args type year debug

clear
set more off
set matsize 3000
set mem 3g

adopath ++ "/public/ado"

local cendatadir = "/rdcprojects/mc1/mc00535/data/decennial/02-Recoded_State_Files/"
local outdatadir = "/rdcprojects/mc1/mc00535/data/decennial/03-State_Files/"
local logs = "/rdcprojects/mc1/mc00535/programs_organize/2.data/2.Decennial/logs/"

cap log close
log using "`logs'/4.Add_POW_Missingness_Weights_to_Statefiles_`type'_`year'.log", replace
timer clear
timer on 1

**** Get list of sample counties
use `cendatadir'/samplelists.dta
levelsof st, local(allstates)
if "`debug'"=="debug" local allstates="06"

bysort county90: keep if _n==1
keep county90
gen samplecounty=1
tempfile samplecounties
save `samplecounties'
clear

**** Get wage deciles for each year in sample counties
use `cendatadir'/wage_deciles`year'.dta, clear
mean lnwage2_*
local lnwage2_p10_`year'=_b[lnwage2_10]
local lnwage2_p20_`year'=_b[lnwage2_20]
local lnwage2_p30_`year'=_b[lnwage2_30]
local lnwage2_p40_`year'=_b[lnwage2_40]
local lnwage2_p50_`year'=_b[lnwage2_50]
local lnwage2_p60_`year'=_b[lnwage2_60]
local lnwage2_p70_`year'=_b[lnwage2_70]
local lnwage2_p80_`year'=_b[lnwage2_80]
local lnwage2_p90_`year'=_b[lnwage2_90]
clear

tempfile predictions
local count=0
**** For each year, loop over sample counties (`samplecounties')
foreach state of local allstates{
	di ""
	if "`type'"=="POR" {
   	   di "Processing state `state', year `year' POR"
	   use "`cendatadir'/dec`year'recoded`state'.dta", clear
	 }
	if "`type'"=="POW" {
	   di "Processing state `state', year `year' POW"
	   use "`cendatadir'/powdec`year'recoded`state'.dta", clear
	   ***** Restrict attention to those with a potentially valid pow
	   keep if inlist(esr,1,4)==1
	 }

	**** Create a year variable to use when merging on weights
	gen year=`year'
	**** Create lnwage2 variable to be conditioned on in creation of wage weights
	gen wage=incw/(wklyrwk*wklyrhr)
	gen lnwage=ln(wage)
	gen lnwage2=lnwage if incwf==0&wklyrwkf==0&wklyrhrf==0
	
	**** Replace missing lnwage2 values with 0 so that all employed individuals can be included in unconditional regression
	****    In the unconditional regression, include the missing lnwage2 dummy 
	gen lnwage2_miss=lnwage2==.
	
	**** Generate lnwage2 polynomial to be used in both regressions
	gen lnwage2_cat=0 if lnwage2_miss==1
	replace lnwage2_cat=1 if  inrange(lnwage2,-999999             ,`lnwage2_p10_`year'')==1 & lnwage2_miss==0 
	replace lnwage2_cat=2 if  inrange(lnwage2,`lnwage2_p10_`year'',`lnwage2_p20_`year'')==1 & lnwage2_miss==0 
	replace lnwage2_cat=3 if  inrange(lnwage2,`lnwage2_p20_`year'',`lnwage2_p30_`year'')==1 & lnwage2_miss==0 
	replace lnwage2_cat=4 if  inrange(lnwage2,`lnwage2_p30_`year'',`lnwage2_p40_`year'')==1 & lnwage2_miss==0 
	replace lnwage2_cat=5 if  inrange(lnwage2,`lnwage2_p40_`year'',`lnwage2_p50_`year'')==1 & lnwage2_miss==0 
	replace lnwage2_cat=6 if  inrange(lnwage2,`lnwage2_p50_`year'',`lnwage2_p60_`year'')==1 & lnwage2_miss==0 
	replace lnwage2_cat=7 if  inrange(lnwage2,`lnwage2_p60_`year'',`lnwage2_p70_`year'')==1 & lnwage2_miss==0 
	replace lnwage2_cat=8 if  inrange(lnwage2,`lnwage2_p70_`year'',`lnwage2_p80_`year'')==1 & lnwage2_miss==0 
	replace lnwage2_cat=9 if  inrange(lnwage2,`lnwage2_p80_`year'',`lnwage2_p90_`year'')==1 & lnwage2_miss==0 
	replace lnwage2_cat=10 if inrange(lnwage2,`lnwage2_p90_`year'',999999              )==1 & lnwage2_miss==0 
	
	**** Recode Broad Age Categories
	gen broadagecat = .
	replace broadagecat=1 if age <=19
	replace broadagecat=2 if 20 <= age & age <= 39
	replace broadagecat=3 if 40 <= age & age <= 64
	replace broadagecat=4 if 65 <= age
	
	**** Recode Broad Educ Categories
	gen broadeduccat = .
	replace broadeduccat = 1 if educcat<= 7
	replace broadeduccat = 2 if educcat == 8
	replace broadeduccat = 3 if educcat >= 9
	replace broadeduccat = 4 if inschool>= 2&inschool!=.
	
	**** Race
	gen racecat = 1 if raceeth == 1
	replace racecat = 2 if raceeth == 2
	replace racecat = 3 if raceeth > 2 & raceeth!=.
	
	**** COW
	destring cow, replace
	recode cow .=-1
	
	if `year'!=1990 {
  	   gen county90=substr(tractid90,1,5)
	   gen powcounty90=substr(powtractid90,1,5)
	 }
	
	joinby county90 using `samplecounties', unmatched(master)
	tab _merge
	drop _merge
	replace samplecounty=0 if samplecounty==.
	
	ren tractid90 tractid90_real
	gen tractid90=tractid90_real if samplecounty==1
	if `year'==1980 replace tractid90=substr(tractid80,1,2)+"000000000" if samplecounty==0
	if `year'==1990 replace tractid90=substr(blockid90,1,2)+"000000000" if samplecounty==0
	if `year'==2000 replace tractid90=substr(blockid00,1,2)+"000000000" if samplecounty==0
	
	joinby tractid90 lnwage2_cat cow year sex broadagecat broadeduccat racecat using "`cendatadir'/County-Year-Demo_POWimputation_IPWs", unmatched(master)
	tab _merge samplecounty
	
	drop _merge
	drop lnwage2_cat broadagecat broadeduccat racecat year
	drop tractid90
	ren tractid90_real tractid90
	
	gen pwgt3=pwgt2
	replace pwgt3=pwgt3*pow_ipw if pow_ipw!=.
	replace pwgt3=. if inlist(esr,1,4)==0
	gen pwgt4=pwgt2
	replace pwgt4=pwgt4*wage_pow_ipw if wage_pow_ipw!=.
	replace pwgt4=. if inlist(esr,1,4)==0 | lnwage2==.
	drop wage lnwage lnwage2
	compress
	
	if "`type'"=="POR" save "`outdatadir'/dec`year'_`state'.dta", replace
	if "`type'"=="POW" save "`outdatadir'/powdec`year'_`state'.dta", replace
}

timer off 1
timer list
di "MINUTES="r(t1)/60
di "HOURS="r(t1)/60/60
cap log close
