***********************************************************************;
**** This program merges output from the geocoding program and,    ****;
****    where possible, fills in the tract variable in non-coded   ****;
****    years with the value of neighboring years                  ****;
***********************************************************************;

%include "/public/programs/sas/savastata.mac";



**** %let home = C:/Documents and Settings/Jesse Gregory/My Documents/Econ/Geocoding;
%let homedir = /rdcprojects/mc1/mc00535;
%let TIGERYEAR = 2000;

/*--- Set paths and librefs. ---------------------------------------*/
/*--- Location of downloaded TIGER files. */
****   %let year_loc=&TIGERYEAR./RT1RT2;
****   %let TIGER_DATA=&homedir/TIGER;
/*--- Location of map spatial data sets and catalog. */
%let MAP_DATA=&homedir/data/geocoding/&TIGERYEAR/Geocoded Street Map;
/*--- Location for street lookup data sets used by geocoder. */
%let LOOKUP_DATA=&homedir/data/geocoding/&TIGERYEAR/Street Lookup Data;
/*--- Location of address data set to be geocoded. */
%let ADDRESS_DATA1=&homedir/data/geocoding/Address Data/01-BatchCodedAddresses/Active_SSL_Active_LBD;
%let ADDRESS_DATA2=&homedir/data/geocoding/Address Data/01-BatchCodedAddresses/Active_SSL_Inavtive_LBD;
%let ADDRESS_DATA3=&homedir/data/geocoding/Address Data/01-BatchCodedAddresses/Miami;
%let TEMP_ADDRESS_DATA=&homedir/data/geocoding/Address Data/02-LongitudinalImp/;
/*--- Set librefs. */
libname STREET "&MAP_DATA";
libname LOOKUP "&LOOKUP_DATA";
libname ADDRESS1 "&ADDRESS_DATA1";
libname ADDRESS2 "&ADDRESS_DATA2";
libname ADDRESS3 "&ADDRESS_DATA3";
libname TempAddr "&TEMP_ADDRESS_DATA";


%macro loops;

%do yr = 1987 %to 2004;
proc sort data = address1.sample_coded&yr;
by lbdnum;
run;

proc sort data = address1.sample_notcoded&yr;
by lbdnum;
run;

proc sort data = address2.sample_coded&yr;
by lbdnum;
run;

proc sort data = address2.sample_notcoded&yr;
by lbdnum;
run;

proc sort data = address3.sample_coded&yr;
by lbdnum;
run;

proc sort data = address3.sample_notcoded&yr;
by lbdnum;
run;
%end;



%do yr = 1987 %to 2004;
data work.address&yr (keep = lbdnum yr tract block beststreet _score_ bestzip5 newfips matchtypenum);
set address1.sample_coded&yr address1.sample_notcoded&yr 
    address2.sample_coded&yr address2.sample_notcoded&yr
    address3.sample_coded&yr address3.sample_notcoded&yr;
by lbdnum;

**** Code matchtype numerically (was address physical business or mailing);
matchtypenum = 0;
if mu = 0 & matchtype = "p" then matchtypenum = 1;
if mu = 1 & yr < 2002 & matchtype = "b" then matchtypenum = 1;
if mu = 1 & yr >= 2002 & matchtype = "p" then matchtypenum = 1;
if mu = 0 & matchtype = "b" & pstreet="" then matchtypenum = 2.0;
else if mu = 0 & matchtype = "b" then matchtypenum = 2.1;
if mu = 0 & matchtype = "m" then matchtypenum = 3.0;

**** Mu establishments always use physical address, but that address is;
**** stored in bstreet before 2002.  This code puts all mu address info in p*;
if mu = 1 & yr < 2002 then pzip5 = bzip5;
if mu = 1 & yr < 2002 then bzip5 = "";
if mu = 1 & yr < 2002 then pstreet = bstreet;
if mu = 1 & yr < 2002 then bstreet = "";

**** Create a single_variable containing the best street address;
beststreet = pstreet;
if 2<=matchtypenum<=2.1 then beststreet = bstreet;
if 3<=matchtypenum<=3.1 then beststreet = mstreet;
if pstreet ne "" & matchtypenum = 0 then beststreet = pstreet;
if pstreet = "" & bstreet ne "" & matchtypenum = 0 then beststreet = bstreet;

**** Create a single_variable containing the best zipcode;
bestzip5 = pzip5;
if 2<=matchtypenum<=2.1 then bestzip5 = bzip5;
if 3<=matchtypenum<=3.1 then bestzip5 = mzip5;
if pzip5 ne "" & matchtypenum = 0 then bestzip5 = pzip5;
if pzip5 = "" & bzip5 ne "" & matchtypenum = 0 then bestzip5 = bzip5;

run;
%end;


data work.Long_Imp_Data;
set
%do yr = 1987 %to 2004;
    work.address&yr 
%end;
;
run;

data work.Long_Imp_Data_01;
set work.Long_Imp_Data;
if (substr(lbdnum,12,1)="0")
or (substr(lbdnum,12,1)="1");
run;

%savastata ("/rdcprojects/mc00535/data/geocoding/Address Data/02-LongitudinalImp/Long_Imp_Data_01.dta", -check -replace);

data work.Long_Imp_Data_23;
set work.Long_Imp_Data;
if (substr(lbdnum,12,1)="2")
or (substr(lbdnum,12,1)="3");
run;

%savastata ("/rdcprojects/mc00535/data/geocoding/Address Data/02-LongitudinalImp/Long_Imp_Data_23.dta", -check -replace);

data work.Long_Imp_Data_456;
set work.Long_Imp_Data;
if (substr(lbdnum,12,1)="4")
or (substr(lbdnum,12,1)="5")
or (substr(lbdnum,12,1)="6");
run;

%savastata ("/rdcprojects/mc00535/data/geocoding/Address Data/02-LongitudinalImp/Long_Imp_Data_456.dta", -check -replace);

data work.Long_Imp_Data_789;
set work.Long_Imp_Data;
if (substr(lbdnum,12,1)="7")
or (substr(lbdnum,12,1)="8")
or (substr(lbdnum,12,1)="9");
run;

%savastata ("/rdcprojects/mc00535/data/geocoding/Address Data/02-LongitudinalImp/Long_Imp_Data_789.dta", -check -replace);

proc datasets lib = work;
delete Long_Imp_Data Long_Imp_Data_01 Long_Imp_Data_23 Long_Imp_Data_456 Long_Imp_Data_789
%do yr = 1987 %to 2004;
    address&yr 
%end;
;
run;
%mend;


%loops;

