**** This do file homogenizes the LBD/SSL, it appends all years and select variables.
**** Written by: Matias.

clear
set mem 15G

global out = "/rdcprojects/mc1/mc00535/data/ssllbd/"
global dir = "/rdcprojects/mc1/mc00535/data/ssllbd/stata_datasets/"
global ezdata = "/rdcprojects/mc1/mc00535/data/ezdata/"
cap log close
log using 4_LBD.log, replace

forvalues y = 1987(1)2004{
	use "$dir/ssllbd`y'_all.dta", clear
	
	cap drop cfn_ssl 
	cap drop cfn_lbd 
	cap drop sce_ssl 
	cap drop cfl_ssl 
	cap drop act_ssl 
	cap drop act_lbd 
	cap drop toc_ssl
	cap drop recnum
	cap drop sslfirmid
	cap drop sce

        ** Sample weights
	cap gen wgt = "00100"
	gen weight = real(substr(wgt,1,3)+"."+substr(wgt,4,5))
	replace weight = 1 if weight ==0
        drop wgt
	
	** Homogenize LFO
	gen LFO = lfo_lbd
	gen LFO_source = "LBD" if LFO!=""
	replace LFO = lfo_ssl if lfo_lbd=="" & lfo_ssl!=""
	replace LFO_source = "SSL" if  lfo_lbd=="" & lfo_ssl!=""
	
	gen aux     = "Corporation " if LFO=="00" | LFO=="02" | LFO=="C"
	replace aux = "Tax-Ex Coorp" if LFO=="01" | LFO=="T"
	replace aux = "Partnership " if LFO=="20" | LFO=="21" | LFO=="22" | LFO=="P"
	replace aux = "Sole Proprie" if LFO=="10" | LFO=="11" | LFO=="12" | LFO=="S"
	replace aux = "Government " if LFO=="50" | LFO=="51" | LFO=="52" | LFO=="G"
	replace aux = "Cooperatives" if LFO=="80" | LFO=="81" | LFO=="82" | LFO=="83" | LFO=="3" | LFO=="4"
	replace aux = "Other       " if LFO=="90" | LFO=="91" | LFO=="92" | LFO=="E"  | LFO=="0" | LFO=="O"
	replace aux = "Uknown      " if LFO=="70" | LFO=="71" | LFO=="72" | LFO=="73" | LFO=="U" 
	drop LFO
	ren aux LFO
	label var LFO "Legal Form of Organization"
	cap drop lfo_ssl
	cap drop lfo_lbd
	
	** Homogenize FIPS
	gen FIPS_source = "LBD" if fips_lbd!=""
	gen FIPS = fips_lbd
	replace FIPS_source = "SSL" if FIPS=="" & newfips!=""
	replace FIPS = newfips if FIPS=="" & newfips!=""
	replace FIPS_source = "SSL" if FIPS=="" & fips_ssl!=""
	replace FIPS = fips_ssl  if FIPS=="" & fips_ssl!=""
	cap drop newfips
	cap drop fips_lbd
	cap drop fips_ssl
	
	** Homogenize SIC
	gen SIC_source = "Best SIC LBD" if bestsic_lbd!=""
	gen SIC = bestsic_lbd
	replace SIC_source = "SIC LBD" if SIC=="" & sic_lbd!=""
	replace SIC = sic_lbd if SIC=="" & sic_lbd!=""
	replace SIC_source = "SIC SSL" if SIC=="" & sic_ssl!=""
	replace SIC = sic_ssl if SIC=="" & sic_ssl!=""
	drop bestsic_lbd
	drop sic_lbd
	drop sic_ssl
	
	gen NAICS = bestnaics_lbd
	gen NAICS_source = "Best NAICS LBD" if NAICS!=""
	drop bestnaics_lbd
	
	drop if notinlbd==1
	drop notinlbd
	
	** Sales, employment and payroll
	ren salereceipt_ssl sales
	
	sum employment_lbd
	replace employment_ssl = . if employment_ssl>r(max)  | employment_ssl<r(min)
	sum employment_ssl
	replace employment_lbd = . if employment_lbd>r(max)  | employment_lbd<r(min)
	
	sum payroll_lbd
	replace payroll_ssl = . if payroll_ssl>r(max)  | payroll_ssl<r(min)
	sum payroll_ssl
	replace payroll_lbd = . if payroll_lbd>r(max)  | payroll_lbd<r(min)
	
	drop employment_ssl 
	drop payroll_ssl
	ren employment_lbd employment
	ren payroll_lbd wagebill
	compress
        save "$dir/erase_`y'", replace
}

use "$dir/erase_1987",clear
forvalues y = 1988(1)2004{
  append using "$dir/erase_`y'"
}
compress
save "$dir/LBD.dta", replace

forvalues y = 1987(1)2004{
  erase "$dir/erase_`y'.dta"
}

******************************
** FIX LABLES               **
******************************

use "$dir/LBD.dta", clear

** More labels

foreach var in flaga firstflag lastflag{
	gen aux2 = `var'
	gen aux = .
	replace aux = 1	  if aux2=="1"
	replace aux = 2	  if aux2=="2"
	replace aux = 3	  if aux2=="3"
	replace aux = 4	  if aux2=="4"
	replace aux = 5	  if aux2=="5"
	replace aux = 6	  if aux2=="6"
	replace aux = 7	  if aux2=="7"
	replace aux = 8	  if aux2=="8"
	replace aux = 9	  if aux2=="A"
	replace aux = 10  if aux2=="B"
	replace aux = 11  if aux2=="C"
	replace aux = 12  if aux2=="D"	
	replace aux = 13  if aux2=="E"
	replace aux = 14  if aux2=="I"
	replace aux = 15  if aux2=="J"
	replace aux = 16  if aux2=="M"
	replace aux = 17  if aux2=="P"
	replace aux = 18  if aux2=="R"
	replace aux = 19  if aux2=="S"
	replace aux = 20  if aux2=="W"
	replace aux = 21  if aux2=="Z"
	drop aux2 
	drop `var'
	ren aux `var' 
}

label var flaga "Type of Link Flag (Source: LBD)"
label var firstflag "First Link Flag"
label var lastflag  "Last Link Flag"


cap label drop lbd_flags
label define lbd_flags 1 "Continuer: Missing year 1", add
label define lbd_flags 2 "Continuer: Missing year 2", add
label define lbd_flags 3 "Birth: Missing year 1", add
label define lbd_flags 4 "Continuer: Missing birth year 1", add
label define lbd_flags 5 "Birth: Repaired initial flag", add
label define lbd_flags 6 "Death: Repaired terminal flag", add
label define lbd_flags 7 "Continuer: Repaired bogus birth", add
label define lbd_flags 8 "Continuer: Repaired bogus death", add
label define lbd_flags 9 "Continuer: Name/Address matched", add
label define lbd_flags 10 "Birth", add
label define lbd_flags 11 "Continuer: CFN/PPN matched", add
label define lbd_flags 12 "Death", add
label define lbd_flags 13 "Continuer: Other", add
label define lbd_flags 14 "Inactive: SSEL Inactive Spell: Begin", add
label define lbd_flags 15 "Inactive: SSEL Inactive Spell: End", add
label define lbd_flags 16 "Continuer: Mid-Year reorg", add
label define lbd_flags 17 "Continuer: PPN matched", add
label define lbd_flags 18 "Birth reorganization", add
label define lbd_flags 19 "Inactive: Apparent inactivity", add
label define lbd_flags 20 "???", add
label define lbd_flags 21 "Continuer: CFN matched", add

label values flaga lbd_flags
label values firstflag lbd_flags
label values lastflag lbd_flags

replace matchtypenum = 4 if matchtypenum==2.1
label variable matchtypenum "Describes Address Used in Geocoding"
cap label drop matchtypenum_lab
label define matchtypenum_lab 0 "SU - Physical Address Match" 1 "MU - Physical Address Match" 2 "SU - Business Address Match - No Physical Address" 4 "SU - Business Address Match - Unmatched Physical Address" 3 "SU - Mailout Address Match"
label values matchtypenum matchtypenum_lab

label variable blockid_imp_f "Missingness Pattern Found When Longitudinally Imputing Geocodes"
cap label drop blockid_imp_f_lab
label define blockid_imp_f_lab 0 "No Longitudinal Imputation" 1 "Imputed - Used Code from Estab-Address but Higher _Score_" 2 "Imputed - Part of Leading String of Missings" 3 "Imputed - Part of a Trailing String of Missings" 4 "Imputed - Part of an interior String of Missings"
label values blockid_imp_f blockid_imp_f_lab

drop cfl

gen aux = .
replace aux = 1  if gsc=="A"
replace aux = 2  if gsc=="B"
replace aux = 3  if gsc=="C"
replace aux = 4  if gsc=="D"
replace aux = 5  if gsc=="E"
replace aux = 6  if gsc=="F"
replace aux = 7  if gsc=="G"
replace aux = 8  if gsc=="H"
replace aux = 9  if gsc=="I"
replace aux = 10 if gsc=="J"
replace aux = 11 if gsc=="K"
replace aux = 12 if gsc=="L"
replace aux = 13 if gsc=="M"
replace aux = 14 if gsc=="N"
replace aux = 15 if gsc=="P"
replace aux = 16 if gsc=="R"
replace aux = 17 if gsc=="V"
replace aux = 18 if gsc=="W"
replace aux = 19 if gsc=="X"
replace aux = 20 if gsc=="Z"
drop gsc
ren aux gsc
label var gsc "Geographic Summary Coding Flag"

cap label drop gsc_lab
label define gsc_lab 1  "Detail coded; high confidence 1", add
label define gsc_lab 2  "Detail coded; high confidence 2", add
label define gsc_lab 3  "Detail coded; medium confidence 1", add
label define gsc_lab 4  "Detail coded; medium confidence 2", add
label define gsc_lab 5  "Header coded; high confidence 3", add
label define gsc_lab 6  "Header coded; medium confidence 3", add
label define gsc_lab 7  "Header coded; low confidence", add
label define gsc_lab 8  "Clerical coding flags", add
label define gsc_lab 9  "Clerical coding flags", add
label define gsc_lab 10 "Clerical coding flags", add
label define gsc_lab 11 "Clerical coding flags", add
label define gsc_lab 12 "Clerical coding flags", add
label define gsc_lab 13 "Clerical coding flags", add
label define gsc_lab 14 "Clerical coding flags", add
label define gsc_lab 15 "Clerical coding flags", add
label define gsc_lab 16 "Referral coding process (under review)", add
label define gsc_lab 17 "Reserved for future use", add
label define gsc_lab 18 "Reserved for future use", add
label define gsc_lab 19 "Front-end coded; not eligible for Detail (ARF) or Header (CRF) match", add
label define gsc_lab 20 "Forced match; not eligible for detail coding", add
label values gsc gsc_lab

cap label drop cenflag_lab
label define cenflag_lab 1 "Census in scope" 0 "Census out-of-scope"
label values cenflag cenflag_lab

gen aux = 1 if asmf=="A"
replace aux = 0 if asmf=="B"
drop asmf
ren aux asmf 
label var asmf "ASM Sample Flag"
cap label drop asmf_lab
label define asmf_lab 1 "Chance for selection into ASM" 0 "No chance of selection into ASM"
label values asmf asmf_lab 

drop flag_i

encode flagb, gen(flagb_n)
drop flagb
ren flagb_n flagb

ren yr year

label var LFO_source "LFO source flag"
label var FIPS "FIPS Code"
label var FIPS_source "FIPS source flag"
label var SIC "SIC Code"
label var SIC_source "SIC source code"
label var SIC_source "SIC source flag"
label var NAICS "NAICS Code"
label var NAICS_source "NAICS source flag"

gen _______FLAGS_______ = ""
label var _______FLAGS_______ "----------------------------------------------------"
gen ________ADM________ = ""
label var ________ADM________ "----------------------------------------------------"

order lbdnum year blockid tractid employment wagebill sales LFO FIPS SIC NAICS _______FLAGS_______ mu firstyear lastyear flaga flagb firstflag lastflag cenflag gsc asmf matchtypenum blockid_imp_f geocode_status LFO_source FIPS_source SIC_source NAICS_source ________ADM________

compress

cap drop ________ADM________
cap drop progid_cons 
cap drop progid_power 
cap drop progname 
cap drop program1995 
cap drop program1999 
cap drop program2001 
cap drop application_tract 
cap drop assigned_tract
cap drop blockid
cap drop tract2000

gen lbdnum_lastdig=substr(lbdnum,12,1)

save "$out/LBD.dta", replace


