**** This do file takes the LBD/SSL and merge it to the administrative file. 
**** It also create new variables that are based on whether the firm is in an EZ or not.
**** Written by: Matias and Jesse.

clear
set more off
global dir = "/rdcprojects/mc1/mc00535/data/ssllbd/"
global ezdata = "/rdcprojects/mc1/mc00535/data/ezdata/"
global geodata = "/rdcprojects/mc1/mc00535/data/geocoding/Address Data/03-FinalGeoFiles/"
global CBRF = "/rdcprojects/mc1/mc00535/data/CBRF"
global geocodeipw = "/rdcprojects/mc1/mc00535/data/Basic_Extract/Geocode_IPWs/"

set mem 5g
cap log close
log using "6_Create_LBD_full.log", text replace

**** Build geocoded data

use "$geodata/blocks_lbdnums1987", clear
forvalues yr = 1988(1)2004 {
append using "$geodata/blocks_lbdnums`yr'"
}
ren yr year
sort lbdnum year

preserve
gen one = 1
collapse (sum) one, by(lbdnum year)
tempfile drops
sort lbdnum year
save `drops', replace
restore

merge lbdnum year using `drops'
drop _merge
drop if one>1   //drops repeated obs (there are around 400)
drop one
sort lbdnum year
save "$dir/blocks_lbdnums.dta", replace

**** Prep CBRF
use "$CBRF/CBRF", clear
gen tractid90 = substr(blockid90,1,11)
bysort blockid00 tractid90: keep if _n==1
egen tractid90_count = sum(1), by(blockid00)
sort blockid00
save "$dir/CBRF.dta", replace

*** Prep admin file for merge by 1990 tract
use "$ezdata/blocklevel_admdata.dta", clear
keep if keep_1990geography==1
keep if program1995!=. | program1999!=. | program2001!=. | application_tract==1 | assigned_tract==1
collapse progid_cons progid_power progname program1995 program1999 program2001 application_tract assigned_tract, by(tract1990)
replace application_tract = 0 if application_tract < 0.5
replace application_tract = 1 if application_tract >=0.5 & application_tract<.
label var progname            "Program identifier"
label var program1995         "Type of treatment in round 1 (1995)"
label var program1999         "Type of treatment in round 2 (1999)"
label var program2001         "Type of treatment in round 3 (2001)"
label var application_tract   "=1 if tract applied in round 1"
label var assigned_tract      "=1 if tract was assigned EZ status in round 1"
label var progid_cons         "Program id, conservative (EZ-1, rejected, future that dont overlap)"
label var progid_power        "Program id more power (EZ-1, union of rejected and future)"
sort tract1990
compress
save "$dir/admin_tract.dta", replace


*** Prep admin file for merge by 2000 block
use "$ezdata/blocklevel_admdata.dta", clear
keep if keep_2000geography==1
keep if program1995!=. | program1999!=. | program2001!=. | application_tract==1 | assigned_tract==1
collapse application_tract assigned_tract, by(blockid2000)
ren blockid2000 blockid00
replace application_tract = 0 if application_tract < 0.5
replace application_tract = 1 if application_tract >=0.5 & application_tract<.
replace assigned_tract = 0 if assigned_tract < 0.5
replace assigned_tract = 1 if assigned_tract >=0.5 & assigned_tract <.
label var application_tract   "=1 if tract applied in round 1"
label var assigned_tract      "=1 if tract was assigned EZ status in round 1"
sort blockid00
compress
save "$dir/admin_block.dta", replace

**** Compile LBD
forval ii = 0/9 {
use  "$dir/LBD_vars`ii'.dta", clear
save "$dir/LBD_full`ii'.dta", replace

**** Merge to geocodes: THIS MERGE SHOULD BE ALMOST PERFECT
use "$dir/LBD_full`ii'.dta", clear
cap drop matchtypenum blockid_imp_f geocode_status
****merge lbdnum year using "$dir/blocks_lbdnums.dta"
joinby lbdnum year using "$dir/blocks_lbdnums.dta", unmatched(master)
tab _merge
drop if _m==2
drop _merge
ren blockid blockid00
sort blockid00
save "$dir/LBD_full`ii'.dta", replace

*** Merge LBD to ADMIN by block2000
*** (This is a one to one merge and the treatment vars will by used only to define panel outcomes that 
***     depend on assigned_tract and application_tract)
*** The majority should be merge==1 (i.e. firms outside zones)
use "$dir/LBD_full`ii'.dta", clear
****merge blockid00 using "$dir/admin_block.dta"
joinby blockid00 using "$dir/admin_block.dta", unmatched(master)
tab _merge
drop if _m==2
drop _m

*** Small fixes
cap drop census
gen census  = (year==1987 | year==1992 | year==1997 | year==2000 | year==2002)
ren retail trade
gen other = government+finance+transport+primary

sort lbdnum year
save "$dir/LBD_full`ii'", replace


******************************
** CONSTRUCT MORE VARIABLES **
******************************
use "$dir/LBD_full`ii'", clear
cap drop id
egen id = group(lbdnum)
tsset id year

** Drop firms with dubious geographic ids (if they appear to move)
cap drop mark 
cap drop mark2
cap drop mark _gsc
cap drop numericblock
cap drop move
cap drop maxmove
cap drop meanL
cap drop demp

* drop firms that move and have low quality geo flags
gen mark = 1 if gsc>6 & gsc<.
egen mark_gsc = max(mark), by(id)
replace mark_gsc = 0 if mark_gsc ==.

egen numericblock = group(blockid00)
gen move = abs(D.numericblock)
egen maxmove = max(move) if mark_gsc ==1 , by(id)
replace mark_gsc = 0 if maxmove ==0
drop if mark_gsc==1
drop mark mark_gsc move maxmove
cap drop mark

* drop firms with no employment
egen meanL = mean(employment), by(id)
drop if meanL==.
drop meanL

* drop firms with too much emp growth
gen demp = abs(ln(employment)-ln(L.employment))
gen mark = demp>3 & demp<. & employment>100
egen mark2 = max(mark), by(id)
drop if mark2==1
drop mark mark2

cap drop mark _gsc
cap drop numericblock
cap drop move
cap drop maxmove
cap drop demp


** create an inzone indicator
egen mean = mean(assigned_tract), by(lbdnum)
replace assigned_tract = 1 if mean==1 & assigned_tract==.
replace assigned_tract = 0 if mean==0 & assigned_tract==.

gen ever_inzone = .
replace ever_inzone = 1 if mean!=.
replace ever_inzone = 0 if mean==.
label var ever_inzone "1 if firm is/was/willbe in an EZ or in a rejected/future zone; 0 otherwise"

gen inzone = (assigned_tract==1 | assigned_tract==0)
label var inzone "1 if firm is in an EZ or in a rejected/future zone; 0 otherwise"

tsset id year
gen movein0  = 1 if continuer0==1 & inzone>L.inzone & inzone==1 & L.inzone<.
gen moveout0 = 1 if continuer0==1 & inzone<L.inzone & inzone==1 & L.inzone<.

**** Classify establishments by how they advanced from five years previous to this year
foreach v in 0 5 10{
	sort id year
	gen lifecycle`v'=.
	replace lifecycle`v'=1 if entry`v'==1 & inzone==1 // born in a zone 
	replace lifecycle`v'=2 if entry`v'==1 & inzone==0 // born outside a zone 
	
	replace lifecycle`v'=3 if continuer`v'==1 & inzone==L`v'.inzone & inzone==1       //continuer in zone
	replace lifecycle`v'=4 if continuer`v'==1 & inzone==L`v'.inzone & inzone==0       //continuer outside a zone
	replace lifecycle`v'=5 if continuer`v'==1 & inzone >L`v'.inzone                   //continuer that moved into a zone
	replace lifecycle`v'=6 if continuer`v'==1 & inzone <L`v'.inzone & L`v'.inzone!=.  //continuer that moved out of a zone
	
	if `v'==0 {
            replace lifecycle`v'=3 if continuer`v'==1 & inzone==1 & year==1987  //continuer in a zone
	    replace lifecycle`v'=4 if continuer`v'==1 & inzone==0 & year==1987  //continuer outside a zone
	}

	if `v'==5 {
            replace lifecycle`v'=3 if continuer`v'==1 & inzone==1 & year<=1991   //continuer in a zone
	    replace lifecycle`v'=4 if continuer`v'==1 & inzone==0 & year<=1991   //continuer outside a zone
	}

	if `v'==10 {
            replace lifecycle`v'=3 if continuer`v'==1 & inzone==1 & year<=1996   //continuer in a zone
	    replace lifecycle`v'=4 if continuer`v'==1 & inzone==0 & year<=1996   //continuer outside a zone
	}

	replace lifecycle`v'=7 if exit`v'==1 & inzone==1   // died in a zone
	replace lifecycle`v'=8 if exit`v'==1 & inzone==0   // died outside a zone
	
	replace lifecycle`v'=9  if entry`v'==1 & exit`v'==1 & inzone==1 // one year establishment inside of a zone
	replace lifecycle`v'=10 if entry`v'==1 & exit`v'==1 & inzone==0 // one year establishment outside of a zone
}


cap label drop lifecycle_lab
label define lifecycle_lab 1 "born in a zone", add
label define lifecycle_lab 2 "born outside a zone", add
label define lifecycle_lab 3 "continuer in a zone", add
label define lifecycle_lab 4 "continuer outside a zone", add
label define lifecycle_lab 5 "continuer that moved into a zone", add
label define lifecycle_lab 6 "continuer that moved out of a zone", add
label define lifecycle_lab 7 "died in a zone", add
label define lifecycle_lab 8 "died outside a zone", add
label define lifecycle_lab 9 "born and died in a zone", add
label define lifecycle_lab 10 "born and died outside a zone", add
label values lifecycle0 lifecycle_lab
label values lifecycle5 lifecycle_lab
label values lifecycle10 lifecycle_lab

label var lifecycle0 "Life cycle categories based on year-2-year transitions"
label var lifecycle5 "Life cycle categories based on 5-year transitions"
label var lifecycle10 "Life cycle categories based on 10-year transitions"


drop application_tract assigned_tract
sort blockid00
save "$dir/LBD_full`ii'", replace


**** Merge to CBRF.
use "$dir/LBD_full`ii'", clear
****joinby blockid00 using "$dir/CBRF.dta", unmatched(both)
joinby blockid00 using "$dir/CBRF.dta", unmatched(master)
tab _merge
drop if _m==2
drop _m
gen wgt = 1
replace wgt = 1/tractid90_count if tractid90_count!=.
ren tractid90 tract1990
sort tract1990

*** Merge LBD to ADMIN file: there should be NO _merge==2
****merge tract1990 using "$dir/admin_tract.dta"
joinby tract1990 using "$dir/admin_tract.dta", unmatched(master)
tab _merge
drop if _m==2
drop _m
ren tract1990 tractid90

*** make sure tract1990 is not missing
gen check = substr(blockid90,1,11)
replace tractid90 = check if tractid90=="" & check!=""
drop check
save "$dir/LBD_full`ii'", replace


*********************************
**** MERGE MISSING WEIGHTS  *****
*********************************
use "$dir/LBD_full`ii'", clear
***** Create categorical employment variable
gen empcat = .
replace empcat = 0 if employment==.
replace empcat = 1 if inrange(employment,0,99)==1
replace empcat = 2 if inrange(employment,100,249)==1
replace empcat = 3 if inrange(employment,250,499)==1
replace empcat = 4 if inrange(employment,500,999)==1
replace empcat = 5 if employment >= 1000 & employment<.
label define empcatlab 0 "Missing Employment" 1 "1-99" 2 "100-249" 3 "250-499" 4 "500-999" 5 ">= 1000"
label values empcat empcatlab

***** Calculate establishment age
gen age = year-firstyear

**** Define major industries
gen indsub = real(substr(SIC,1,2))
gen majorind = 11
replace majorind =  1 if inrange(indsub,1,9)==1
replace majorind =  2 if inrange(indsub,10,14)==1
replace majorind =  3 if inrange(indsub,15,17)==1
replace majorind =  4 if inrange(indsub,20,39)==1
replace majorind =  5 if inrange(indsub,40,49)==1
replace majorind =  6 if inrange(indsub,50,51)==1
replace majorind =  7 if inrange(indsub,52,59)==1
replace majorind =  8 if inrange(indsub,60,67)==1
replace majorind =  9 if inrange(indsub,70,88)==1
replace majorind = 10 if inrange(indsub,90,99)==1

label define majindlab 1 "Aggriculture, Forrestry, Fishing" /*
*/    2 "Mining" /*
*/    3 "Construction" /*
*/    4 "Manufacturing" /*
*/    5 "Transportation, Public Utilities" /*
*/    6 "Retail Trade" /*
*/    7 "Wholesale Trade" /*
*/    8 "Finance, Insurance, R.E. Institutions" /*
*/    9 "Services" /*
*/    10 "Other/Govt" /*
*/    11 "Missing"

label values majorind majindlab

gen county90 = substr(tractid90,1,5) 
replace county90 = "12025" if county90=="12086"

ren year yr
sort county90 yr mu majorind empcat age
****merge county90 yr mu majorind empcat age using "$geocodeipw/County-Year_Multivariate_Geocode_IPWs.dta"
joinby county90 yr mu majorind empcat age using "$geocodeipw/County-Year_Multivariate_Geocode_IPWs.dta", unmatched(master)
tab _merge
ren yr year
drop _merge county90 majorind empcat age
replace geocode_ipw = 1 if geocode_ipw==.
gen _W = wgt*geocode_ipw

compress
save "$dir/LBD_full`ii'", replace
}

cap log close
