**** This do file make tract level birth, death, JC, JD variables.
**** It also collapses the LBD by tract.
**** Written by: Matias.

clear
set mem 9G

**set mem 3G
**local deb = "_debug"

global dir = "/rdcprojects/mc1/mc00535/data/ssllbd/"
global ezdata = "/rdcprojects/mc1/mc00535/data/ezdata/"
global progs = "/rdcprojects/mc1/mc00535/programs/matias/LBD_data/"
global results = "/rdcprojects/mc1/mc00535/programs/matias/results/"

cap log close
log using "7_LBD_collapse.log", text replace

forval jj = 1/2 {
if `jj'==1 local cond = "real(substr(tractid90,1,2))<=27"
if `jj'==2 local cond = "real(substr(tractid90,1,2))>=28"

************************
***  BIRTHS-DEATHS   ***
************************
use "$dir/LBD_full0.dta", clear
keep if `cond'
forval ii = 1/9 {
append using "$dir/LBD_full`ii'.dta"
keep if `cond'
}

ren tractid90 tract1990
collapse (sum) establishments entry0 exit0 movein0 moveout0, by(tract1990 year) fast
drop if tract1990 ==""
gen     census = 1 if year==1987
replace census = 2 if year>1987 & year<=1992
replace census = 3 if year>1992 & year<=1997
replace census = 4 if year>1997 & year<=2002
gen longdiffyears = (year>1992 & year<=2000)

ren entry0 birth
ren exit0 death
ren movein0 movein
ren moveout0 moveout

foreach var in birth death movein moveout{
	sort tract1990 year
	by tract1990: gen aux2 = sum(`var') if census==2
	by tract1990: gen aux3 = sum(`var') if census==3
	by tract1990: gen aux4 = sum(`var') if census==4
	by tract1990: gen aux5 = sum(`var') if longdiffyears==1
	gen `var's = 0 if year==1987
	replace `var's = aux2 if year==1992
	replace `var's = aux3 if year==1997
	replace `var's = aux4 if year==2002
	replace `var's = aux5 if year==2000
	cap drop aux*
}

keep if year==1987 | year==1992 | year==1997 | year==2000 | year==2002
keep tract1990 year births deaths moveins moveouts
sort tract1990 year
save "$dir/entryexit`jj'.dta", replace


*****************************
***  BASIC LBD COLLAPSE   ***
*****************************
use "$dir/LBD_full0.dta", clear
keep if `cond'

forval ii = 1/9 {
append using "$dir/LBD_full`ii'.dta"
keep if `cond'
}

ren tractid90 tract1990
keep if census==1
drop census

local categories = "construction manufacture trade services other selfemp micro small medlarge"
foreach var in employment establishments{
   foreach sector in `categories'{
   gen `var'_`sector'=`var'*`sector'
  } 
}

** definition of large: L>=6
cap drop aux
cap drop aux2
gen aux = employment if year==1992
egen aux2 = mean(aux), by(id)
sum aux2, de
gen large = aux2>=6 if aux2!=.
gen largenow=employment>=6 if employment!=.

drop aux aux2

gen lnavrgwage         =ln(wage)
gen lnavrgwage_less5   =ln(wage) if large==0
gen lnavrgwage_more5   =ln(wage) if large==1
gen lnavrgwage_92univ  =ln(wage) if large!=.
gen lnavrgwage_less5now=ln(wage) if largenow==0
gen lnavrgwage_more5now=ln(wage) if largenow==1

foreach var in lnavrgwage lnavrgwage_less5 lnavrgwage_more5 lnavrgwage_92univ lnavrgwage_less5now lnavrgwage_more5now {
   gen empX`var' = employment * `var'
   }

gen wagebill_less5=wagebill    if large==0
gen wagebill_more5=wagebill    if large==1
gen wagebill_92univ=wagebill   if large!=.
gen wagebill_less5now=wagebill if largenow==0
gen wagebill_more5now=wagebill if largenow==1

gen employment_less5=employment if large==0
gen employment_more5=employment if large==1
gen employment_92univ=employment  if large!=.
gen establishments_less5 = 1-large
gen establishments_more5 = large
gen establishments_92univ  = (large!=.)

gen employment_less5now=employment if largenow==0
gen employment_more5now=employment if largenow==1
gen establishments_less5now = 1-largenow
gen establishments_more5now = largenow

collapse (sum) establishments* employment* empX* wagebill wagebill_* cumsumGJC cumsumGJD (mean) wage lnavrgwage lnavrgwage_* JC JD [iw=_W], by(year tract1990) fast
recode lnavrgwage* (0=.)

label variable lnavrgwage          "Establisment-weighted mean of mean establishment wage"
label variable lnavrgwage_less5    "Establisment-weighted mean of mean establishment wage - small firms in 1992"
label variable lnavrgwage_more5    "Establisment-weighted mean of mean establishment wage - large firms in 1992"
label variable lnavrgwage_92univ   "Establisment-weighted mean of mean establishment wage - firms born since 1992"
label variable lnavrgwage_less5now "Establisment-weighted mean of mean establishment wage - current small firms"
label variable lnavrgwage_more5now "Establisment-weighted mean of mean establishment wage - current large firms"

gen lnavrgwage2          = empXlnavrgwage          / employment
gen lnavrgwage2_less5    = empXlnavrgwage_less5    / employment_less5
gen lnavrgwage2_more5    = empXlnavrgwage_more5    / employment_more5
gen lnavrgwage2_92univ   = empXlnavrgwage_92univ   / employment_92univ
gen lnavrgwage2_less5now = empXlnavrgwage_less5now / employment_less5now
gen lnavrgwage2_more5now = empXlnavrgwage_more5now / employment_more5now
drop empX*

label variable lnavrgwage2          "Employment-weighted mean of mean establishment wage"
label variable lnavrgwage2_less5    "Employment-weighted mean of mean establishment wage - small firms in 1992"
label variable lnavrgwage2_more5    "Employment-weighted mean of mean establishment wage - large firms in 1992"
label variable lnavrgwage2_92univ   "Employment-weighted mean of mean establishment wage - firms born since 1992"
label variable lnavrgwage2_less5now "Employment-weighted mean of mean establishment wage - current small firms"
label variable lnavrgwage2_more5now "Employment-weighted mean of mean establishment wage - current large firms"

drop if tract1990 ==""
order tract1990 year
sort tract1990 year
merge tract1990 year using "$dir/entryexit`jj'.dta"
drop if _m==2
drop _m

sort tract1990 year
merge tract1990 using "$dir/admin_tract.dta"
drop if _m==2
drop _m
egen id = group(tract1990)
order id

** Log variables
ren wage wages

gen lnest = ln(establishments)
gen lnest_less5 = ln(establishments_less5)
gen lnest_more5 = ln(establishments_more5)
gen lnest_92univ  = ln(establishments_92univ)
gen lnest_less5now = ln(establishments_less5now)
gen lnest_more5now = ln(establishments_more5now)

gen lnemp = ln(employment)
gen lnemp_less5 = ln(employment_less5)
gen lnemp_more5 = ln(employment_more5)
gen lnemp_92univ  = ln(employment_92univ)
gen lnemp_less5now = ln(employment_less5now)
gen lnemp_more5now = ln(employment_more5now)

gen lnwages = ln(wages)           //some values missing
gen lnwagebill = ln(wagebill)
*gen lnavrgwage=ln(avrgwage)
gen lnwagebill_less5 = ln(wagebill_less5)
gen lnwagebill_more5 = ln(wagebill_more5)
gen lnwagebill_92univ  = ln(wagebill_92univ)
gen lnwagebill_less5now = ln(wagebill_less5now)
gen lnwagebill_more5now = ln(wagebill_more5now)

** Change variables
gen yr = 1 if year==1987
replace yr = 2 if year==1992
replace yr = 3 if year==1997
replace yr = 4 if year==2000
replace yr = 5 if year==2002

compress
sort tract1990 year
save "$dir/LBD_collapsed`jj'.dta", replace

************************************
***  VARIABLES IN LBD COLLAPSE   ***
************************************
use "$dir/LBD_collapsed`jj'.dta", clear
tsset id yr

foreach var in lnemp lnest lnwages lnwagebill{
 gen     d_`var' = d.`var'
 replace d_`var' = `var'-l2.`var' if year>=2000
}

gen     emp_change = 2*(employment-L.employment)/(employment+L.employment)   if year==1997
replace emp_change = 2*(employment-L2.employment)/(employment+L2.employment) if year==2000
replace emp_change = 2*(employment-L3.employment)/(employment+L3.employment) if year==2002
replace emp_change = 0 if (employment+L.employment) ==0 & year==1997
replace emp_change = 0 if (employment+L2.employment) ==0 & year==2000
replace emp_change = 0 if (employment+L3.employment) ==0 & year==2002

foreach cat in `categories'{
	gen     emp_change_`cat' = 2*(employment_`cat'-L.employment_`cat')/(employment_`cat'+L.employment_`cat')   if year==1997
	replace emp_change_`cat' = 2*(employment_`cat'-L2.employment_`cat')/(employment_`cat'+L2.employment_`cat') if year==2000
	replace emp_change_`cat' = 2*(employment_`cat'-L3.employment_`cat')/(employment_`cat'+L3.employment_`cat') if year==2002
	replace emp_change_`cat' = 0 if (employment_`cat'+L.employment_`cat') ==0 & year==1997
	replace emp_change_`cat' = 0 if (employment_`cat'+L2.employment_`cat') ==0 & year==2000
	replace emp_change_`cat' = 0 if (employment_`cat'+L3.employment_`cat') ==0 & year==2002
}

foreach var in deaths births cumsumGJC cumsumGJD moveins moveouts{
   gen     `var'_change = 2*(`var'/5-L.`var'/5)/(`var'/5+L.`var'/5) if inlist(year,1992,1997)==1
   replace `var'_change = 2*(`var'/8-L2.`var'/5)/(`var'/8+L2.`var'/5) if year==2000
   replace `var'_change = 2*(`var'/5-L3.`var'/5)/(`var'/5+L3.`var'/5) if year==2002
   replace `var'_change = 0 if (`var'/5+L.`var'/5)==0 & inlist(year,1992,1997)==1
   replace `var'_change = 0 if (`var'/8+L2.`var'/5)==0&year==2000
   replace `var'_change = 0 if (`var'/5+L3.`var'/5)==0&year==2002
}

sort tract1990 year
save "$dir/LBD_collapsed`jj'.dta", replace
}


use "$dir/LBD_collapsed1.dta"
append using "$dir/LBD_collapsed2.dta"
sort tract1990 year
save "$dir/LBD_collapsed.dta", replace


cap log close

