**** This do file makes a (1990) Census-tract level annual panel of employment, establishments, and average wages from 1987-2004.
**** Written by: Jesse.

clear
clear matrix
set mem 3G

global dir = "/rdcprojects/mc1/mc00535/data/ssllbd/"
global ezdata = "/rdcprojects/mc1/mc00535/data/ezdata/"
global progs = "/rdcprojects/mc1/mc00535/programs/matias/LBD_data/"
global results = "/rdcprojects/mc1/mc00535/programs/matias/results/"

cap log close
log using "R1.LBD_simple_annual_collapse.log", text replace

*****************************
***  BASIC LBD COLLAPSE   ***
*****************************
use lbdnum tractid90 year employment wage wagebill establishments _W using "$dir/LBD_full0.dta", clear
tempfile work
save `work'
forval ii=1/9 {
use lbdnum tractid90 year employment wage wagebill establishments _W using "$dir/LBD_full`ii'.dta", clear
append using `work'
save `work', replace
}

gen largenow=employment >=6 if employment!=.

gen lnavrgwage=ln(wage)

gen lnavrgwage_more5now=ln(wage) if largenow==1
gen lnavrgwage_less5now=ln(wage) if largenow==0
gen establishments_more5now=establishments if largenow==1
gen establishments_less5now=establishments if largenow==0
gen wagebill_less5now=wagebill if largenow==0
gen wagebill_more5now=wagebill if largenow==1
gen employment_less5now=employment if largenow==0
gen employment_more5now=employment if largenow==1

foreach var in lnavrgwage lnavrgwage_less5now lnavrgwage_more5now {
   gen empX`var' = employment * `var'
   }

collapse (sum) establishments* employment* empX* wagebill* (mean) lnavrgwage* (rawsum) _W [iw=_W], by(year tractid90) fast

label variable lnavrgwage          "Establisment-weighted mean of mean establishment wage"
label variable lnavrgwage_less5now "Establisment-weighted mean of mean establishment wage - current small firms"
label variable lnavrgwage_more5now "Establisment-weighted mean of mean establishment wage - current large firms"

gen lnavrgwage2          = empXlnavrgwage          / employment
gen lnavrgwage2_less5now = empXlnavrgwage_less5now / employment_less5now
gen lnavrgwage2_more5now = empXlnavrgwage_more5now / employment_more5now
drop empX*

label variable lnavrgwage2          "Employment-weighted mean of mean establishment wage"
label variable lnavrgwage2_less5now "Employment-weighted mean of mean establishment wage - current small firms"
label variable lnavrgwage2_more5now "Employment-weighted mean of mean establishment wage - current large firms"

drop if tractid90 ==""

compress
order tractid90 year
sort tractid90 year
save "$dir/LBD_simple_annual_panel.dta", replace

log close



