args year geo weight debug

clear mata
clear matrix
clear
version 10.1
set mem 2g
global codes  = "/rdcprojects/mc1/mc00535/programs_organize/2.data/4.BuildWork/"
run "$codes/library.ado"

cap log close
log using "$codes/logs/3.build_POW_`geo'_`year'.log", replace
run "$codes/library.ado"
timer clear
timer on 1

use "$placebo/placebo_tracts_raw.dta", clear
keep tractid90 assigned_placebo assigned_placeboclose assigned_placebofar
tempfile placebos
save `placebos', replace

use "$placebo/placebo_tracts_raw.dta", clear
keep tractid90 assigned_placebo assigned_placeboclose assigned_placebofar
ren tractid90 powtractid90
ren assigned_placebo powassigned_placebo
ren assigned_placeboclose powassigned_placeboclose
ren assigned_placebofar powassigned_placebofar
tempfile powplacebos
save `powplacebos', replace

*** obtain all values of state for serializing
use "$data/samplelists.dta", clear
levelsof st, local(allstates)

** if "`debug'"=="debug" local allstates="$DEBUG"
if "`debug'"=="debug" local allstates="13"
if "`geo'"=="block" local allstates="06 13 17 24 26 34 36 39 42"
if "`debug'"=="debug"&"`geo'"=="block" local allstates="13"

local c = 1
foreach st of local allstates{
  use "$data/samplelists.dta" if st=="`st'", clear
  levelsof county90, local(allcounties)
  foreach s of local allcounties{
        di "currently processing county `s' in `year'"
        clear
        if `year'==1980 local restriction = "& (powcounty80f!=1&powtractid80f!=1)"
        if `year'==1990 local restriction = "& (pow90f1!=1&pow90f2!=1&pow90f3!=1&pow90f4!=1&pow90f5!=1)"
        if `year'==2000 local restriction = "& (inrange(powf1,1,5)!=1 & inrange(powf3,1,5)!=1 & inrange(powf5,1,5)!=1)"

	use "$data/powdec`year'_`st'.dta" if powcounty90=="`s'" `restriction'

	qui count
	if r(N)>0{	
	
        cap drop _merge
        joinby tractid90 using `placebos', unmatched(master)
        replace assigned_placebo=2 if assigned_tract==1
        replace assigned_placeboclose=2 if assigned_tract==1
        replace assigned_placebofar=2 if assigned_tract==1
        label define assigned_placebo_lab 1 "selected placebo tract" 2 "EZ tract"
        label values assigned_placebo assigned_placebo_lab
        label values assigned_placeboclose assigned_placebo_lab
        label values assigned_placebofar assigned_placebo_lab
        drop _merge

        joinby powtractid90 using `powplacebos', unmatched(master)
        replace powassigned_placebo=2 if powassigned_tract==1
        replace powassigned_placeboclose=2 if powassigned_tract==1
        replace powassigned_placebofar=2 if powassigned_tract==1
        label values powassigned_placebo assigned_placebo_lab
        label values powassigned_placeboclose assigned_placebo_lab
        label values powassigned_placebofar assigned_placebo_lab
        drop _merge


	**** when unweighted collapse is requested, set all weights to 1
	if "`weight'"=="noweight" {
	   foreach wgt in pwgt2 pwgt3 pwgt4 {
	      cap replace `wgt' = pwgt
	      }
           replace hwgt2=hwgt
	   }

	gen employed=1 if esr!=0
	replace employed=0 if esr==3|esr==6
	gen unemployed=esr==3 if esr!=0&esr!=6
	gen lfp=esr!=6 if esr!=0

	replace incw=. if incw==0
	
	**** Recode Broad Age Categories
	gen broadagecat = .
	replace broadagecat=1 if age <=19
	replace broadagecat=2 if 20 <= age & age <= 39
	replace broadagecat=3 if 40 <= age & age <= 64
	replace broadagecat=4 if 65 <= age
	
	**** Recode Broad Educ Categories
	gen broadeduccat = .
	replace broadeduccat = 1 if educcat<= 7
	replace broadeduccat = 2 if educcat == 8
	replace broadeduccat = 3 if educcat >= 9
	replace broadeduccat = 4 if inschool>= 2&inschool<.
	
	**** Race
	gen racecat = 1 if raceeth == 1
	replace racecat = 2 if raceeth == 2
	replace racecat = 3 if raceeth > 2 & raceeth<.

	gen black=raceeth==2
	replace black=. if raceeth==.
	gen gt65=age>=65
	replace gt65=. if age==.
	gen lt18=age<18
	replace lt18=. if age==.
        
        gen byte male=sex==1
	gen college=educcat>=10
	replace college=. if educcat==.|educcat==0|age<25
	gen dropout=(educcat>=4&educcat<=7)
	replace dropout=. if educcat==.|educcat==0|age<25
	
	gen byte   male_employed=employed if male==1
	gen byte female_employed=employed if male==0
	gen byte   dropout_employed=employed if dropout==1
	gen byte graduate_employed=employed if dropout==0

	gen double wage=incw/(wklyrwk*wklyrhr)
	gen double lnwage=ln(wage)
	gen double lnwage2=lnwage if incwf==0&wklyrwkf==0&wklyrhrf==0

	gen double wkwage=incw/(wklyrwk)
	gen double lnwkwage=ln(wkwage)
	gen double lnwkwage2=lnwkwage if incwf==0&wklyrwkf==0

	gen double lnincw2=ln(incw) if incwf==0

	*Winsorize at 80% and 40x min wage
	if `year'==1980{
	replace lnwage2=log(.8*2.90) if lnwage2<log(.8*2.90)
	replace lnwage2=log(40*2.90) if lnwage2>log(40*2.90)&lnwage2!=.
	}
	if `year'==1990{
	replace lnwage2=log(.8*3.35) if lnwage2<log(.8*3.35)
	replace lnwage2=log(40*3.35) if lnwage2>log(40*3.35)&lnwage2!=.
	}
	if `year'==2000{
	replace lnwage2=log(.8*5.15) if lnwage2<log(.8*5.15)
	replace lnwage2=log(40*5.15) if lnwage2>log(40*5.15)&lnwage2!=.
	}

	gen double lnwage2_pow = lnwage2

	gen double male_lnwage2_pow = lnwage2 if male==1
	gen double female_lnwage2_pow = lnwage2 if male==0

	gen double dropout_lnwage2_pow = lnwage2 if dropout==1
	gen double graduate_lnwage2_pow = lnwage2 if dropout==0


	gen double lnwage2_local   =lnwage2 if assigned_tract==powassigned_tract&powassigned_tract!=.
	gen double lnwage2_nonlocal=lnwage2 if assigned_tract!=powassigned_tract&powassigned_tract!=.

	gen double male_lnwage2_local   =lnwage2 if male==1 & assigned_tract==powassigned_tract&powassigned_tract!=.
	gen double male_lnwage2_nonlocal=lnwage2 if male==1 & assigned_tract!=powassigned_tract&powassigned_tract!=.

	gen double female_lnwage2_local   =lnwage2 if male==0 & assigned_tract==powassigned_tract&powassigned_tract!=.
	gen double female_lnwage2_nonlocal=lnwage2 if male==0 & assigned_tract!=powassigned_tract&powassigned_tract!=.

	gen double dropout_lnwage2_local   =lnwage2 if dropout==1 & assigned_tract==powassigned_tract&powassigned_tract!=.
	gen double dropout_lnwage2_nonlocal=lnwage2 if dropout==1 & assigned_tract!=powassigned_tract&powassigned_tract!=.

	gen double graduate_lnwage2_local   =lnwage2 if dropout==0 & assigned_tract==powassigned_tract&powassigned_tract!=.
	gen double graduate_lnwage2_nonlocal=lnwage2 if dropout==0 & assigned_tract!=powassigned_tract&powassigned_tract!=.




	gen double lnwage2_local_placebo=lnwage2 if assigned_placebo==powassigned_placebo&powassigned_placebo!=.
	gen double lnwage2_nonlocal_placebo=lnwage2 if assigned_placebo!=powassigned_placebo&powassigned_placebo!=.

	gen double lnwkwage2_pow = lnwkwage2

	gen double male_lnwkwage2_pow = lnwkwage2 if male==1
	gen double female_lnwkwage2_pow = lnwkwage2 if male==0

	gen double dropout_lnwkwage2_pow = lnwkwage2 if dropout==1
	gen double graduate_lnwkwage2_pow = lnwkwage2 if dropout==0


	gen double lnwkwage2_local   =lnwkwage2 if assigned_tract==powassigned_tract&powassigned_tract!=.
	gen double lnwkwage2_nonlocal=lnwkwage2 if assigned_tract!=powassigned_tract&powassigned_tract!=.

	gen double male_lnwkwage2_local   =lnwkwage2 if male==1 & assigned_tract==powassigned_tract&powassigned_tract!=.
	gen double male_lnwkwage2_nonlocal=lnwkwage2 if male==1 & assigned_tract!=powassigned_tract&powassigned_tract!=.

	gen double female_lnwkwage2_local   =lnwkwage2 if male==0 & assigned_tract==powassigned_tract&powassigned_tract!=.
	gen double female_lnwkwage2_nonlocal=lnwkwage2 if male==0 & assigned_tract!=powassigned_tract&powassigned_tract!=.

	gen double dropout_lnwkwage2_local   =lnwkwage2 if dropout==1 & assigned_tract==powassigned_tract&powassigned_tract!=.
	gen double dropout_lnwkwage2_nonlocal=lnwkwage2 if dropout==1 & assigned_tract!=powassigned_tract&powassigned_tract!=.

	gen double graduate_lnwkwage2_local   =lnwkwage2 if dropout==0 & assigned_tract==powassigned_tract&powassigned_tract!=.
	gen double graduate_lnwkwage2_nonlocal=lnwkwage2 if dropout==0 & assigned_tract!=powassigned_tract&powassigned_tract!=.


	gen double lnwkwage2_local_placebo=lnwkwage2 if assigned_placebo==powassigned_placebo&powassigned_placebo!=.
	gen double lnwkwage2_nonlocal_placebo=lnwkwage2 if assigned_placebo!=powassigned_placebo&powassigned_placebo!=.

	gen double lnincw2_pow = lnincw2

	gen double lnincw2_local   =lnincw2 if assigned_tract==powassigned_tract&powassigned_tract!=.
	gen double lnincw2_nonlocal=lnincw2 if assigned_tract!=powassigned_tract&powassigned_tract!=.

	gen double lnincw2_local_placebo=lnincw2 if assigned_placebo==powassigned_placebo&powassigned_placebo!=.
	gen double lnincw2_nonlocal_placebo=lnincw2 if assigned_placebo!=powassigned_placebo&powassigned_placebo!=.

	gen double jobs_local=employed if assigned_tract==powassigned_tract&powassigned_tract!=.
	gen double jobs_nonlocal=employed if assigned_tract!=powassigned_tract&powassigned_tract!=.

	gen double jobs_local_wage=employed if assigned_tract==powassigned_tract&powassigned_tract!=.&lnwage2_local!=.
	gen double jobs_nonlocal_wage=employed if assigned_tract!=powassigned_tract&powassigned_tract!=.&lnwage2_nonlocal!=.


	gen double male_jobs_local=employed if male==1 & assigned_tract==powassigned_tract&powassigned_tract!=.
	gen double male_jobs_nonlocal=employed if male==1 & assigned_tract!=powassigned_tract&powassigned_tract!=.

	gen double female_jobs_local=employed if male==0 & assigned_tract==powassigned_tract&powassigned_tract!=.
	gen double female_jobs_nonlocal=employed if male==0 & assigned_tract!=powassigned_tract&powassigned_tract!=.

	gen double dropout_jobs_local=employed if dropout==1 & assigned_tract==powassigned_tract&powassigned_tract!=.
	gen double dropout_jobs_nonlocal=employed if dropout==1 & assigned_tract!=powassigned_tract&powassigned_tract!=.

	gen double graduate_jobs_local=employed if dropout==0 & assigned_tract==powassigned_tract&powassigned_tract!=.
	gen double graduate_jobs_nonlocal=employed if dropout==0 & assigned_tract!=powassigned_tract&powassigned_tract!=.



 	run "$codes/code_industries.do" `year'
        cap drop bygroup 
        egen bygroup = group(pow`geo'id90)
	forval ind=1/12 {
	gen double ind`ind'_jobs_local=employed if assigned_tract==powassigned_tract&powassigned_tract!=. & ind1==`ind'
	gen double ind`ind'_jobs_nonlocal=employed if assigned_tract!=powassigned_tract&powassigned_tract!=. & ind1==`ind'
	gen double ind`ind'_lnwage2_local=lnwage2_local if assigned_tract==powassigned_tract&powassigned_tract!=. & ind1==`ind'
	gen double ind`ind'_lnwage2_nonlocal=lnwage2_nonlocal if assigned_tract!=powassigned_tract&powassigned_tract!=. & ind1==`ind'
	reweightvar, var(ind`ind'_lnwage2_local) weight(pwgt4) by(bygroup)
	reweightvar, var(ind`ind'_lnwage2_nonlocal) weight(pwgt4) by(bygroup)
	}

	gen double lnwage2_zoneres =lnwage2 if assigned_tract==1
	gen double lnwage2_nonzoneres =lnwage2 if assigned_tract!=1

	gen double lnwkwage2_zoneres =lnwkwage2 if assigned_tract==1
	gen double lnwkwage2_nonzoneres =lnwkwage2 if assigned_tract!=1

	gen double lnincw2_zoneres =lnincw2 if assigned_tract==1
	gen double lnincw2_nonzoneres =lnincw2 if assigned_tract!=1

	gen double jobs_zoneres=employed if assigned_tract==1
	gen double jobs_nonzoneres=employed if assigned_tract!=1

	gen double earn_local=incw if assigned_tract==powassigned_tract&powassigned_tract!=.
	gen double earn_nonlocal=incw if assigned_tract!=powassigned_tract&powassigned_tract!=.

	gen double lnwage2_local_placeboclose=lnwage2 if assigned_placeboclose==powassigned_placeboclose&powassigned_placeboclose!=.
        gen double lnwage2_nonlocal_placeboclose=lnwage2 if assigned_placeboclose!=powassigned_placeboclose&powassigned_placeboclose!=.

	gen double lnwage2_local_placebofar=lnwage2 if assigned_placebofar==powassigned_placebofar&powassigned_placebofar!=.
	gen double lnwage2_nonlocal_placebofar=lnwage2 if assigned_placebofar!=powassigned_placebofar&powassigned_placebofar!=.

	gen double lnwkwage2_local_placeboclose=lnwkwage2 if assigned_placeboclose==powassigned_placeboclose&powassigned_placeboclose!=.
        gen double lnwkwage2_nonlocal_placeboclose=lnwkwage2 if assigned_placeboclose!=powassigned_placeboclose&powassigned_placeboclose!=.

	gen double lnwkwage2_local_placebofar=lnwkwage2 if assigned_placebofar==powassigned_placebofar&powassigned_placebofar!=.
	gen double lnwkwage2_nonlocal_placebofar=lnwkwage2 if assigned_placebofar!=powassigned_placebofar&powassigned_placebofar!=.

	gen double lnincw2_local_placeboclose=lnincw2 if assigned_placeboclose==powassigned_placeboclose&powassigned_placeboclose!=.
        gen double lnincw2_nonlocal_placeboclose=lnincw2 if assigned_placeboclose!=powassigned_placeboclose&powassigned_placeboclose!=.

	gen double lnincw2_local_placebofar=lnincw2 if assigned_placebofar==powassigned_placebofar&powassigned_placebofar!=.
	gen double lnincw2_nonlocal_placebofar=lnincw2 if assigned_placebofar!=powassigned_placebofar&powassigned_placebofar!=.

	gen jobs_local_placebo=employed if assigned_placebo==powassigned_placebo&powassigned_placebo!=.
	gen jobs_nonlocal_placebo=employed if assigned_placebo!=powassigned_placebo&powassigned_placebo!=.

	gen jobs_local_placebofar=employed if assigned_placebofar==powassigned_placebofar&powassigned_placebofar!=.
	gen jobs_nonlocal_placebofar=employed if assigned_placebofar!=powassigned_placebofar&powassigned_placebofar!=.

	gen jobs_local_placeboclose=employed if assigned_placeboclose==powassigned_placeboclose&powassigned_placeboclose!=.
	gen jobs_nonlocal_placeboclose=employed if assigned_placeboclose!=powassigned_placeboclose&powassigned_placeboclose!=.


        cap drop bygroup 
        egen bygroup = group(pow`geo'id90)
	reweightvar, var(lnwage2_pow) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwage2_local) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwage2_nonlocal) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwage2_zoneres) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwage2_nonzoneres) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwage2_local_placebo) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwage2_nonlocal_placebo) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwage2_local_placeboclose) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwage2_nonlocal_placeboclose) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwage2_local_placebofar) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwage2_nonlocal_placebofar) weight(pwgt4) by(bygroup)

	reweightvar, var(male_lnwage2_pow) weight(pwgt4) by(bygroup)
        reweightvar, var(male_lnwage2_local) weight(pwgt4) by(bygroup)
        reweightvar, var(male_lnwage2_nonlocal) weight(pwgt4) by(bygroup)
	reweightvar, var(female_lnwage2_pow) weight(pwgt4) by(bygroup)
        reweightvar, var(female_lnwage2_local) weight(pwgt4) by(bygroup)
        reweightvar, var(female_lnwage2_nonlocal) weight(pwgt4) by(bygroup)
	reweightvar, var(dropout_lnwage2_pow) weight(pwgt4) by(bygroup)
        reweightvar, var(dropout_lnwage2_local) weight(pwgt4) by(bygroup)
        reweightvar, var(dropout_lnwage2_nonlocal) weight(pwgt4) by(bygroup)
	reweightvar, var(graduate_lnwage2_pow) weight(pwgt4) by(bygroup)
        reweightvar, var(graduate_lnwage2_local) weight(pwgt4) by(bygroup)
        reweightvar, var(graduate_lnwage2_nonlocal) weight(pwgt4) by(bygroup)


	reweightvar, var(lnwkwage2_pow) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwkwage2_local) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwkwage2_nonlocal) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwkwage2_zoneres) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwkwage2_nonzoneres) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwkwage2_local_placebo) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwkwage2_nonlocal_placebo) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwkwage2_local_placeboclose) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwkwage2_nonlocal_placeboclose) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwkwage2_local_placebofar) weight(pwgt4) by(bygroup)
        reweightvar, var(lnwkwage2_nonlocal_placebofar) weight(pwgt4) by(bygroup)

	reweightvar, var(male_lnwkwage2_pow) weight(pwgt4) by(bygroup)
        reweightvar, var(male_lnwkwage2_local) weight(pwgt4) by(bygroup)
        reweightvar, var(male_lnwkwage2_nonlocal) weight(pwgt4) by(bygroup)
	reweightvar, var(female_lnwkwage2_pow) weight(pwgt4) by(bygroup)
        reweightvar, var(female_lnwkwage2_local) weight(pwgt4) by(bygroup)
        reweightvar, var(female_lnwkwage2_nonlocal) weight(pwgt4) by(bygroup)
	reweightvar, var(dropout_lnwkwage2_pow) weight(pwgt4) by(bygroup)
        reweightvar, var(dropout_lnwkwage2_local) weight(pwgt4) by(bygroup)
        reweightvar, var(dropout_lnwkwage2_nonlocal) weight(pwgt4) by(bygroup)
	reweightvar, var(graduate_lnwkwage2_pow) weight(pwgt4) by(bygroup)
        reweightvar, var(graduate_lnwkwage2_local) weight(pwgt4) by(bygroup)
        reweightvar, var(graduate_lnwkwage2_nonlocal) weight(pwgt4) by(bygroup)



	reweightvar, var(lnincw2_pow) weight(pwgt4) by(bygroup)
        reweightvar, var(lnincw2_local) weight(pwgt4) by(bygroup)
        reweightvar, var(lnincw2_nonlocal) weight(pwgt4) by(bygroup)
        reweightvar, var(lnincw2_zoneres) weight(pwgt4) by(bygroup)
        reweightvar, var(lnincw2_nonzoneres) weight(pwgt4) by(bygroup)
        reweightvar, var(lnincw2_local_placebo) weight(pwgt4) by(bygroup)
        reweightvar, var(lnincw2_nonlocal_placebo) weight(pwgt4) by(bygroup)
        reweightvar, var(lnincw2_local_placeboclose) weight(pwgt4) by(bygroup)
        reweightvar, var(lnincw2_nonlocal_placeboclose) weight(pwgt4) by(bygroup)
        reweightvar, var(lnincw2_local_placebofar) weight(pwgt4) by(bygroup)
        reweightvar, var(lnincw2_nonlocal_placebofar) weight(pwgt4) by(bygroup)


	**Ns**
	/* I want actual number of micro-obs -- Pat 10/19/11
	gen N_jobs=pwgt3^2 if employed!=.
	gen N_jobs_local=pwgt3^2 if jobs_local!=.
	gen N_jobs_nonlocal=pwgt3^2 if jobs_nonlocal!=.
	*/

	gen N_jobs=1 if employed!=.
	gen N_jobs_local=1 if jobs_local!=.
	gen N_jobs_nonlocal=1 if jobs_nonlocal!=.

	global collapsevars "lnwage2_pow lnwage2_local lnwage2_nonlocal male_lnwage2_pow male_lnwage2_local male_lnwage2_nonlocal female_lnwage2_pow female_lnwage2_local female_lnwage2_nonlocal male_lnwkwage2_pow male_lnwkwage2_local male_lnwkwage2_nonlocal female_lnwkwage2_pow female_lnwkwage2_local female_lnwkwage2_nonlocal lnwage2_zoneres lnwage2_nonzoneres lnwage2_local_placebo lnwage2_nonlocal_placebo lnwage2_local_placeboclose lnwage2_nonlocal_placeboclose lnwage2_local_placebofar lnwage2_nonlocal_placebofar lnwkwage2_pow lnwkwage2_local lnwkwage2_nonlocal lnwkwage2_zoneres lnwkwage2_nonzoneres lnwkwage2_local_placebo lnwkwage2_nonlocal_placebo lnwkwage2_local_placeboclose lnwkwage2_nonlocal_placeboclose lnwkwage2_local_placebofar lnwkwage2_nonlocal_placebofar      lnincw2_pow lnincw2_local lnincw2_nonlocal lnincw2_zoneres lnincw2_nonzoneres lnincw2_local_placebo lnincw2_nonlocal_placebo lnincw2_local_placeboclose lnincw2_nonlocal_placeboclose lnincw2_local_placebofar lnincw2_nonlocal_placebofar"

        global pricevars = ""
	foreach var in $collapsevars{
	  if strpos("`var'","ln")!=0 global pricevars "$pricevars `var'"
	}
        global pricevars : list uniq global pricevars 
        foreach var in $pricevars{
          local varname = substr("N_`var'",1,32)
          gen `varname' = 1 if `var'!=.
        }

	#delimit ;
	collapse 
		(mean) black_pow=black male_pow=male hisp_pow=hisp age_pow=age gt65_pow=gt65 lt18_pow=lt18 college_pow=college dropout_pow=dropout 
		(sum) jobs=employed male_jobs=male_employed female_jobs=female_employed dropout_jobs=dropout_employed graduate_jobs=graduate_employed jobs_local jobs_nonlocal jobs_local_wage jobs_nonlocal_wage male_jobs_local male_jobs_nonlocal female_jobs_local female_jobs_nonlocal dropout_jobs_local dropout_jobs_nonlocal graduate_jobs_local graduate_jobs_nonlocal ind*_jobs_local ind*_jobs_nonlocal jobs_zoneres jobs_nonzoneres jobs_local_placebo jobs_local_placebofar jobs_local_placeboclose jobs_nonlocal_placebo jobs_nonlocal_placebofar jobs_nonlocal_placeboclose earnings=incw earn_local earn_nonlocal 
		(rawsum) lnwage2_pow lnwage2_local lnwage2_nonlocal male_lnwage2_pow male_lnwage2_local male_lnwage2_nonlocal female_lnwage2_pow female_lnwage2_local female_lnwage2_nonlocal male_lnwkwage2_pow male_lnwkwage2_local male_lnwkwage2_nonlocal female_lnwkwage2_pow female_lnwkwage2_local female_lnwkwage2_nonlocal dropout_lnwage2_pow dropout_lnwage2_local dropout_lnwage2_nonlocal graduate_lnwage2_pow graduate_lnwage2_local graduate_lnwage2_nonlocal dropout_lnwkwage2_pow dropout_lnwkwage2_local dropout_lnwkwage2_nonlocal graduate_lnwkwage2_pow graduate_lnwkwage2_local graduate_lnwkwage2_nonlocal lnwage2_zoneres lnwage2_nonzoneres lnwage2_local_placebo lnwage2_nonlocal_placebo lnwage2_local_placeboclose lnwage2_nonlocal_placeboclose lnwage2_local_placebofar lnwage2_nonlocal_placebofar      lnwkwage2_pow lnwkwage2_local lnwkwage2_nonlocal lnwkwage2_zoneres lnwkwage2_nonzoneres lnwkwage2_local_placebo lnwkwage2_nonlocal_placebo lnwkwage2_local_placeboclose lnwkwage2_nonlocal_placeboclose lnwkwage2_local_placebofar lnwkwage2_nonlocal_placebofar      lnincw2_pow lnincw2_local lnincw2_nonlocal lnincw2_zoneres lnincw2_nonzoneres lnincw2_local_placebo lnincw2_nonlocal_placebo lnincw2_local_placeboclose lnincw2_nonlocal_placeboclose lnincw2_local_placebofar lnincw2_nonlocal_placebofar
		ind*_lnwage2_local ind*_lnwage2_nonlocal     
		N_* 
		[iw=pwgt3], by(pow`geo'id90) fast;
	#delimit cr

	recode *ln*wage2_* (0=.)
	recode lnwkwage2_* (0=.)
	recode lnincw2_* (0=.)

	gen lnjobs=ln(jobs)
	gen lnearnings=ln(earnings)

	
	if "`weight'"=="noweight" {
	   foreach var of varlist * {
	      cap ren `var' `var'_nwt
	      if _rc!=0 drop `var'
	      }
	   foreach var in pow`geo'id90 {
	      ren `var'_nwt `var'
	      }
	   }

        gen year=`year'
	
	tempfile demo_`c'
	save `demo_`c'', replace
        local c = `c'+1
	}
  }
}

use `demo_1', clear
local c = `c'-1
forvalues s = 2(1)`c'{
  append using `demo_`s''
}
if "`geo'"=="tract" ren powtractid90 tractid90
if "`geo'"=="block" ren powblockid90 blockid90
compress
if "`weight'"!="noweight" {
save "$intermediate/pow`year'_`geo'", replace
}
if "`weight'"=="noweight" {
save "$intermediate/pow`year'_`geo'_noweight", replace
}

timer off 1
timer list
di "MINUTES="r(t1)/60
di "HOURS="r(t1)/60/60
cap log close

