args debug

clear mata
clear matrix
clear
version 10.1
set mem 2g
set more off
global codes  = "/rdcprojects/mc1/mc00535/programs_organize/2.data/4.BuildWork/"
cap log close
log using "$codes/logs/4.build_MigrationLog.log", replace
run "$codes/library.ado"
timer clear
timer on 1

*** obtain all values of state for serializing
use "$data/samplelists.dta", clear
levelsof st, local(allstates)
if "`debug'"=="debug" local allstates="$DEBUG"

local c = 1
foreach st of local allstates{
  use "$data/samplelists.dta" if st=="`st'", clear
  levelsof county90, local(allcounties)
  foreach s of local allcounties{
        di "currently processing county `s'"
        clear
	*****************************************************************
	******** Estimate Migration Betas from base year 1980  **********
	*****************************************************************
	use assigned_tract program1995 age raceeth educcat tractid90 pwgt2 county90 using "$data/dec1980_`st'.dta" if county90=="`s'" , clear
        gen year = 1980 
	tempfile winlose80
	save `winlose80', replace
	
	use assigned_tract program1995 age ymi90 raceeth educcat tractid90 pwgt2 county90 using "$data/dec1990_`st'.dta" if county90=="`s'", clear
        gen year = 1990
	append using `winlose80'
	
	gen year1990=year==1990
	sum year1990
	local share1990=r(mean)
	
	**** Temporary fix
	replace assigned_tract=1 if program1995==3
	keep if (year==1980 & inrange(age,19,999)==1) | (year==1990 & inlist(ymi90,4,5,6)==1 & inrange(age,29,999)==1)
	
	gen all = 1
	gen black = raceeth==2 if raceeth<.
	gen nonblack = 1-black
	gen dropout = inrange(educcat,1,7)==1 if educcat<.
	gen nondropout = 1-dropout
	gen dropout_assigned_tract=dropout*assigned_tract
	gen young=age<30 if year==1980 & age != .
	replace young=age<40 if year==1990 & age != .
	gen old=1-young
	label variable young "under 30 in 1980"
	
	keep tractid90 year1990 all dropout nondropout young old black nonblack assigned_tract dropout_assigned_tract pwgt2
	egen tractN_1980 = sum(year1990==0), by(tractid90)
	egen tractN_1990all = sum( year1990 ), by(tractid90)
	egen tractN_1990dropout = sum( year1990*dropout ), by(tractid90)
	egen tractN_1990nondropout = sum( year1990*(1-dropout) ), by(tractid90)
	egen tractN_1990young = sum( year1990*young ), by(tractid90)
	egen tractN_1990nonyoung = sum( year1990*(1-young) ), by(tractid90)
	egen tractN_1990black = sum( year1990*black ), by(tractid90)
	egen tractN_1990nonblack = sum( year1990*(1-black) ), by(tractid90)
	
	**** Keep tracts with over 100 1980 observations that are not perfectly predicted
	preserve
	keep if tractN_1980 > 100
	drop if tractN_1990all == 0
	egen tractnum = group(tractid90)
	qui sum tractnum
	local tractcount_all = r(max)
	tempfile tempcen_all
	save `tempcen_all', replace
	restore
	
	**** Keep tracts with over 100 1980 observations that are not perfectly predicted by dropout status
	preserve
	keep if tractN_1980 > 100
	drop if tractN_1990dropout == 0
	drop if tractN_1990nondropout == 0
	egen tractnum = group(tractid90)
	qui sum tractnum
	local tractcount_dropout = r(max)
	tempfile tempcen_dropout
	save `tempcen_dropout', replace
	restore
	
	**** Keep tracts with over 100 1980 observations that are not perfectly predicted by young status
	preserve
	keep if tractN_1980 > 100
	drop if tractN_1990young == 0
	drop if tractN_1990nonyoung == 0
	egen tractnum = group(tractid90)
	qui sum tractnum
	local tractcount_young = r(max)
	tempfile tempcen_young
	save `tempcen_young', replace
	restore
	
	**** Keep tracts with over 100 1980 observations that are not perfectly predicted by black status
	keep if tractN_1980 > 100
	drop if tractN_1990black == 0
	drop if tractN_1990nonblack == 0
	egen tractnum = group(tractid90)
	qui sum tractnum
	local tractcount_black = r(max)
	tempfile tempcen_black
	save `tempcen_black', replace
	
	**** Estimate migration logits all
	tempfile coefficients
	forvalues ii=1(1)`tractcount_all' {
		di `ii'
		use `tempcen_all' if tractnum == `ii', clear
		ml model lf miglogit_lf (year1990=all, noconstant) [pw=pwgt2]
		cap ml maximize, iterate(100)
		keep if _n==1
		gen beta_all = _b[all]
		gen converged=e(converged)
		keep tractid90 assigned_tract beta_all converged
		gen baseyear=1980
		if `ii'>1 append using `coefficients'
		save `coefficients', replace
	}
        tempfile baseyear80_allbetas_`c'
        save `baseyear80_allbetas_`c'', replace
	
	**** Estimate migration logits dropouts
	tempfile coefficients
	forvalues ii=1(1)`tractcount_dropout' {
		di `ii'
		use `tempcen_dropout' if tractnum == `ii', clear
		ml model lf miglogit_lf (year1990=dropout nondropout, noconstant) [pw=pwgt2]
		cap ml maximize, iterate(100)
		keep if _n==1
		gen beta_nondropout = _b[nondropout]
		gen beta_dropout = _b[dropout]
		gen converged=e(converged)
		keep tractid90 assigned_tract beta_nondropout beta_dropout converged
		gen baseyear=1980
		if `ii'>1 append using `coefficients'
		save `coefficients', replace
	}
        tempfile baseyear80_dropoutbetas_`c'
        save `baseyear80_dropoutbetas_`c'', replace

	**** Estimate migration logits young
	tempfile coefficients
	forvalues ii=1(1)`tractcount_young' {
		di `ii'
		use `tempcen_young' if tractnum == `ii', clear
		ml model lf miglogit_lf (year1990=young old, noconstant) [pw=pwgt2]
		cap ml maximize, iterate(100)
		keep if _n==1
		gen beta_old = _b[old]
		gen beta_young = _b[young]
		gen converged=e(converged)
		keep tractid90 assigned_tract beta_old beta_young converged
		gen baseyear=1980
		if `ii'>1 append using `coefficients'
		save `coefficients', replace
	}
        tempfile baseyear80_youngbetas_`c'
        save `baseyear80_youngbetas_`c'', replace
	
	**** Estimate migration logits black
	tempfile coefficients
	forvalues ii=1(1)`tractcount_black' {
		di `ii'
		use `tempcen_black' if tractnum == `ii', clear
		ml model lf miglogit_lf (year1990=black nonblack, noconstant) [pw=pwgt2]
		cap ml maximize, iterate(100)
		keep if _n==1
		gen beta_nonblack = _b[nonblack]
		gen beta_black = _b[black]
		gen converged=e(converged)
		keep tractid90 assigned_tract beta_nonblack beta_black converged
		gen baseyear=1980
		if `ii'>1 append using `coefficients'
		save `coefficients', replace
	}
        tempfile baseyear80_blackbetas_`c'
        save `baseyear80_blackbetas_`c'', replace
	
	
	*****************************************************************
	******** Estimate Migration Betas from base year 1990  **********
	*****************************************************************
	use assigned_tract program1995 age ymi00 raceeth educcat tractid90 pwgt2 county90 using "$data/dec2000_`st'.dta" if county90=="`s'", clear
        gen year = 2000 
        tempfile winlose2000
        save `winlose2000', replace

	use assigned_tract program1995 age ymi90 raceeth educcat tractid90 pwgt2 county90 using "$data/dec1990_`st'.dta" if county90=="`s'", clear
        gen year = 1990 
	append using `winlose2000'

	gen year2000=year==2000
	sum year2000
	local share2000=r(mean)
	
	**** Temporary fix
	replace assigned_tract=1 if program1995==3
	keep if (year==1990 & inrange(age,19,999)==1) | (year==2000 & inlist(ymi00,4,5,6)==1 & inrange(age,29,999)==1)
	gen all = 1
	gen black = raceeth==2 if raceeth!=.
	gen nonblack = 1-black
	gen dropout = inrange(educcat,1,7)==1 if educcat!=.
	gen dropout_assigned_tract=dropout*assigned_tract
	gen nondropout = 1-dropout
	gen young=age<30 if year==1990 & age != .
	replace young=age<40 if year==2000 & age != .
	gen old=1-young
	label variable young "under 30 in 1990"
	
	keep tractid90 year2000 all dropout nondropout young old black nonblack assigned_tract dropout_assigned_tract pwgt2
	egen tractN_1990 = sum(year2000==0), by(tractid90)
	egen tractN_2000all = sum( year2000 ), by(tractid90)
	egen tractN_2000dropout = sum( year2000*dropout ), by(tractid90)
	egen tractN_2000nondropout = sum( year2000*(1-dropout) ), by(tractid90)
	egen tractN_2000young = sum( year2000*young ), by(tractid90)
	egen tractN_2000nonyoung = sum( year2000*(1-young) ), by(tractid90)
	egen tractN_2000black = sum( year2000*black ), by(tractid90)
	egen tractN_2000nonblack = sum( year2000*(1-black) ), by(tractid90)
	
	
	**** Keep tracts with over 100 1990 observations that are not perfectly predicted by dropout status
	preserve
	keep if tractN_1990 > 100
	drop if tractN_2000all == 0
	egen tractnum = group(tractid90)
	qui sum tractnum
	local tractcount_all = r(max)
	tempfile tempcen_all
	save `tempcen_all', replace
	restore
	
	**** Keep tracts with over 100 1990 observations that are not perfectly predicted by dropout status
	preserve
	keep if tractN_1990 > 100
	drop if tractN_2000dropout == 0
	drop if tractN_2000nondropout == 0
	egen tractnum = group(tractid90)
	qui sum tractnum
	local tractcount_dropout = r(max)
	tempfile tempcen_dropout
	save `tempcen_dropout', replace
	restore
	
	**** Keep tracts with over 100 1990 observations that are not perfectly predicted by young status
	preserve
	keep if tractN_1990 > 100
	drop if tractN_2000young == 0
	drop if tractN_2000nonyoung == 0
	egen tractnum = group(tractid90)
	qui sum tractnum
	local tractcount_young = r(max)
	tempfile tempcen_young
	save `tempcen_young', replace
	restore
	
	**** Keep tracts with over 100 1990 observations that are not perfectly predicted by black status
	keep if tractN_1990 > 100
	drop if tractN_2000black == 0
	drop if tractN_2000nonblack == 0
	egen tractnum = group(tractid90)
	qui sum tractnum
	local tractcount_black = r(max)
	tempfile tempcen_black
	save `tempcen_black', replace
	
	**** Estimate migration logits all
	tempfile coefficients
	forvalues ii= 1(1)`tractcount_all' {
		di `ii'
		use `tempcen_all' if tractnum == `ii', clear
		ml model lf miglogit_lf (year2000=all, noconstant) [pw=pwgt2]
		cap ml maximize, iterate(100)
		keep if _n==1
		gen beta_all = _b[all]
		gen converged=e(converged)
		keep tractid90 assigned_tract beta_all converged
		gen baseyear=1990
		if `ii'>1 append using `coefficients'
		save `coefficients', replace
	}
        tempfile baseyear90_allbetas_`c'
        save `baseyear90_allbetas_`c'', replace
	
	**** Estimate migration logits dropouts
	tempfile coefficients
	forvalues ii= 1(1)`tractcount_dropout' {
		di `ii'
		use `tempcen_dropout' if tractnum == `ii', clear
		ml model lf miglogit_lf (year2000=dropout nondropout, noconstant) [pw=pwgt2]
		cap ml maximize, iterate(100)
		keep if _n==1
		gen beta_nondropout = _b[nondropout]
		gen beta_dropout = _b[dropout]
		gen converged=e(converged)
		keep tractid90 assigned_tract beta_nondropout beta_dropout converged
		gen baseyear=1990
		if `ii'>1 append using `coefficients'
		save `coefficients', replace
	}
        tempfile baseyear90_dropoutbetas_`c'
        save `baseyear90_dropoutbetas_`c'', replace
	
	**** Estimate migration logits young
	tempfile coefficients
	forvalues ii= 1(1)`tractcount_young' {
		di `ii'
		use `tempcen_young' if tractnum == `ii', clear
		ml model lf miglogit_lf (year2000=young old, noconstant) [pw=pwgt2]
		cap ml maximize, iterate(100)
		keep if _n==1
		gen beta_old = _b[old]
		gen beta_young = _b[young]
		gen converged=e(converged)
		keep tractid90 assigned_tract beta_old beta_young converged
		gen baseyear=1990
		if `ii'>1 append using `coefficients'
		save `coefficients', replace
	}
        tempfile baseyear90_youngbetas_`c'
        save `baseyear90_youngbetas_`c'', replace
	
	**** Estimate migration logits black
	tempfile coefficients
	forvalues ii=1(1)`tractcount_black' {
		di `ii'
		use `tempcen_black' if tractnum == `ii', clear
		ml model lf miglogit_lf (year2000=black nonblack, noconstant) [pw=pwgt2]
		cap ml maximize, iterate(100)
		keep if _n==1
		gen beta_nonblack = _b[nonblack]
		gen beta_black = _b[black]
		gen converged=e(converged)
		keep tractid90 assigned_tract beta_nonblack beta_black converged
		gen baseyear=1990
		if `ii'>1 append using `coefficients'
		save `coefficients', replace
	}

        tempfile baseyear90_blackbetas_`c'
        save `baseyear90_blackbetas_`c'', replace
	local c = `c'+1
  }
}



*** APPEND MIG LOGITS DATASET
local c = `c'-1
use `baseyear80_allbetas_1', clear
  forvalues s = 2(1)`c'{
    append using `baseyear80_allbetas_`s''
   }
compress
save "$intermediate/baseyear80_allbetas", replace

use `baseyear80_dropoutbetas_1', clear
  forvalues s = 2(1)`c'{
    append using `baseyear80_dropoutbetas_`s''
   }
compress
save "$intermediate/baseyear80_dropoutbetas", replace


use `baseyear80_youngbetas_1', clear
  forvalues s = 2(1)`c'{
    append using `baseyear80_youngbetas_`s''
   }
compress
save "$intermediate/baseyear80_youngbetas", replace

use `baseyear80_blackbetas_1', clear
  forvalues s = 2(1)`c'{
    append using `baseyear80_blackbetas_`s''
   }
compress
save "$intermediate/baseyear80_blackbetas", replace

use `baseyear90_allbetas_1', clear
  forvalues s = 2(1)`c'{
    append using `baseyear90_allbetas_`s''
   }
compress
save "$intermediate/baseyear90_allbetas", replace

use `baseyear90_dropoutbetas_1', clear
  forvalues s = 2(1)`c'{
    append using `baseyear90_dropoutbetas_`s''
   }
compress
save "$intermediate/baseyear90_dropoutbetas", replace

use `baseyear90_blackbetas_1', clear
  forvalues s = 2(1)`c'{
    append using `baseyear90_blackbetas_`s''
   }
compress
save "$intermediate/baseyear90_blackbetas", replace

use `baseyear90_youngbetas_1', clear
  forvalues s = 2(1)`c'{
    append using `baseyear90_youngbetas_`s''
   }
compress
save "$intermediate/baseyear90_youngbetas", replace



timer off 1
timer list
di "MINUTES="r(t1)/60
di "HOURS="r(t1)/60/60
cap log close
