args sample debug
clear mata
clear matrix
clear
version 10.1
set mem 2g
global codes  = "/rdcprojects/mc1/mc00535/programs_organize/2.data/4.BuildWork/"
run "$codes/library.ado"

cap log close
log using "$codes/logs/6.build_lnwage_`sample'.log", replace
timer clear
timer on 1

***********************************************************************************
*** This is used to record diagnostics from the variable-adjustment regressions ***
***********************************************************************************
tempname memhold
tempfile results
postfile `memhold' str20(state area) str20(outcome) double(N df_m) using "`results'"

local listbase = "pwgt2 pwgt3 pwgt4 progid_power tractid90 assigned_tract powprogid_power powtractid90 powassigned_tract sex educcat age raceeth esr incw wklyrwk wklyrhr incwf wklyrwkf wklyrhrf inschool pov sample_winlose sample_winlose_pow county90 powcounty90" 
local list1980 = "mig80 tractid80 powcounty80f powtractid80f"
local list1990 = "mig pow90f1 pow90f2 pow90f3 pow90f4 pow90f5 pern"
local list2000 = "mig blockid00 powf1 powf3 powf5 pern "

*** obtain all values of state for serializing
use "$data/samplelists.dta", clear
levelsof st, local(allstates)

if "`debug'"=="debug" local allstates="13"
local c = 1
foreach s of local allstates{
        di "currently processing state `s'"
	*********************************************************************
	***** Create a recoded housing and person dataset for each year *****
	*********************************************************************
	tempfile tempcen

	if "`sample'"=="outside"{
	use `listbase' `list1980' using "$data/dec1980_`s'.dta" if sample_winlose==1, clear
	ren mig80 mig 
 	gen year = 1980
	save `tempcen', replace
	
	use `listbase' `list1990' using "$data/dec1990_`s'.dta" if sample_winlose==1, clear
 	gen year = 1990
	append using `tempcen'
	save `tempcen', replace
	
	use `listbase' `list2000' using "$data/dec2000_`s'.dta" if sample_winlose==1, clear
 	gen year = 2000
	append using `tempcen'
	}

	if "`sample'"=="pow"{
	use `listbase' `list1980' using "$data/powdec1980_`s'.dta" if sample_winlose_pow==1, clear
	ren mig80 mig 
 	gen year = 1980
	save `tempcen', replace
	
	use `listbase' `list1990' using "$data/powdec1990_`s'.dta" if sample_winlose_pow==1, clear
 	gen year = 1990
	append using `tempcen'
	save `tempcen', replace
	
	use `listbase' `list2000' using "$data/powdec2000_`s'.dta" if sample_winlose_pow==1, clear
 	gen year = 2000
	append using `tempcen'
	}

	**********************************************
	**** Gen Variables, weights and cells     ****
	**********************************************
	
	****** Fill "pern" variable with wage income for 1980
	replace pern = 0 if year==1980 & age>=15
	replace pern = incw if year==1980 & incw!=.
	
	**** Recode Broad Age Categories
	gen byte broadagecat = .
	replace broadagecat=1 if age <=19
	replace broadagecat=2 if 20 <= age & age <= 39
	replace broadagecat=3 if 40 <= age & age <= 64
	replace broadagecat=4 if 65 <= age
	
	**** Recode Broad Educ Categories
	gen byte broadeduccat = .
	replace broadeduccat = 1 if educcat<= 7
	replace broadeduccat = 2 if educcat == 8
	replace broadeduccat = 3 if educcat >= 9
	replace broadeduccat = 4 if inschool>= 2&inschool!=.
	
	**** Race
	gen byte racecat = 1 if raceeth == 1
	replace racecat = 2 if raceeth == 2
	replace racecat = 3 if raceeth > 2 & raceeth!=.
	
	***Covariates***
	gen agesq=age^2
	gen age3=age^3
	gen age4=age^4
	gen byte black=racecat==2
	gen byte other=racecat==3
	gen byte male=sex==1
	gen byte hsdrop  =broadeduccat==1 if broadeduccat!=.
	gen byte hs      =broadeduccat==2 if broadeduccat!=.
	gen byte coll    =broadeduccat==3 if broadeduccat!=.
	replace inschool=broadeduccat==4 if broadeduccat!=.
	
	**** Wages and Jobs
	gen employed=1 if esr!=0
	replace employed=0 if esr==3|esr==6
	
	gen double wage  =incw/(wklyrwk*wklyrhr)
	gen double lnwage=ln(wage)
	gen double lnwage2=lnwage if incwf==0 & wklyrwkf==0 & wklyrhrf==0

	gen double wkwage  =incw/(wklyrwk)
	gen double lnwkwage=ln(wkwage)
	gen double lnwkwage2=lnwkwage if incwf==0 & wklyrwkf==0

	*Winsorize at 80% and 40x min wage
	replace lnwage2=log(.8*2.90) if lnwage2<log(.8*2.90)&year==1980
	replace lnwage2=log(40*2.90) if lnwage2>log(40*2.90)&year==1980&lnwage2!=.
	replace lnwage2=log(.8*3.35) if lnwage2<log(.8*3.35)&year==1990
	replace lnwage2=log(40*3.35) if lnwage2>log(40*3.35)&year==1990&lnwage2!=.
	replace lnwage2=log(.8*5.15) if lnwage2<log(.8*5.15)&year==2000
	replace lnwage2=log(40*5.15) if lnwage2>log(40*5.15)&year==2000&lnwage2!=.
	
	gen lnincw=ln(incw)
	gen lnincw2=ln(incw) if incwf==0

	gen lnwage2_pow     =lnwage2	
	gen lnwage2_local   =lnwage2 if assigned_tract==powassigned_tract & powassigned_tract!=.
	gen lnwage2_nonlocal=lnwage2 if assigned_tract!=powassigned_tract & powassigned_tract!=.
	gen lnwage2_outside =lnwage2 if assigned_tract!=powassigned_tract & assigned_tract!=. & powtractid90!=""
	
	gen lnwkwage2_pow     =lnwkwage2	
	gen lnwkwage2_local   =lnwkwage2 if assigned_tract==powassigned_tract & powassigned_tract!=.
	gen lnwkwage2_nonlocal=lnwkwage2 if assigned_tract!=powassigned_tract & powassigned_tract!=.
	gen lnwkwage2_outside =lnwkwage2 if assigned_tract!=powassigned_tract & assigned_tract!=. & powtractid90!=""
	
	gen lnincw2_pow     =lnincw2	
	gen lnincw2_local   =lnincw2 if assigned_tract==powassigned_tract & powassigned_tract!=.
	gen lnincw2_nonlocal=lnincw2 if assigned_tract!=powassigned_tract & powassigned_tract!=.
	gen lnincw2_outside =lnincw2 if assigned_tract!=powassigned_tract & assigned_tract!=. & powtractid90!=""
	
	
	foreach x in lnwage2_pow lnwage2_local lnwage2_nonlocal lnwage2_outside     lnwkwage2_pow lnwkwage2_local lnwkwage2_nonlocal lnwkwage2_outside       lnincw2_pow lnincw2_local lnincw2_nonlocal lnincw2_outside{
	replace `x' = . if year == 1980 & (powcounty80f==1|powtractid80f==1)
	replace `x' = . if year == 1990 & (pow90f1==1|pow90f2==1|pow90f3==1|pow90f4==1|pow90f5==1)
	replace `x' = . if year == 2000 & (inrange(powf1,1,5)==1|inrange(powf3,1,5)==1|inrange(powf5,1,5)==1)
	}

        **** Fix ids
        cap drop progid_power powprogid_power
        gen     progid_power = county90+"0"
        replace progid_power = county90+"1" if assigned_tract==1
        replace progid_power = county90+"2" if assigned_tract==0

        gen     powprogid_power = powcounty90+"0"
        replace powprogid_power = powcounty90+"1" if powassigned_tract==1
        replace powprogid_power = powcounty90+"2" if powassigned_tract==0
	drop county90 powcounty90


	************LOCAL vs. NONLOCAL**********
	if "`sample'"=="pow"{
	**DATA FOR POW VARS**
	keep year pwgt3 pwgt4 lnwage2_pow lnwage2_local lnwage2_nonlocal    lnwkwage2_pow lnwkwage2_local lnwkwage2_nonlocal    lnincw2_pow lnincw2_local lnincw2_nonlocal age agesq age3 age4/* 
           */ hs coll inschool black other male progid_power powprogid_power powtractid90 sample_winlose_pow
	keep if sample_winlose_pow==1&pwgt4!=.
	
	**** Identifiers
	egen countyid=group(progid_power)
	egen powcountyid=group(powprogid_power)
	
	***Demean for areg

	foreach var of varlist age agesq age3 age4 hs coll inschool black other male{	        
	        gen double aux1=`var'*pwgt4
		egen double aux2=sum(pwgt4) if `var'!=.&year==1990, by(powcountyid)
		egen double `var'_mean=sum(aux1/aux2) if `var'!=.&year==1990, by(powcountyid)
		egen double `var'_mean2=mean(`var'_mean), by(powcountyid) //fillin for other decades
		gen double dev_`var'=`var'-`var'_mean2
		drop `var' `var'_mean `var'_mean2 aux1 aux2
	}
	
	compress
	tempfile tempcenperson_pow
	save `tempcenperson_pow', replace	


	
	***** Write the maximum countyid to a local macro
	use `tempcenperson_pow', clear
	sum powcountyid
	local powcitycount = r(max)
	
	tempfile predicted
	forvalues ii = 1(1)`powcitycount' {
	di `ii'
	use `tempcenperson_pow' if powcountyid==`ii', clear
	
	egen powtract_year = group(powtractid90 year)
	foreach var in  lnwage2_pow lnwage2_local lnwage2_nonlocal   lnwkwage2_pow lnwkwage2_local lnwkwage2_nonlocal   lnincw2_pow lnincw2_local lnincw2_nonlocal{

	cap drop `var'_hat
	cap drop `var'_comp
	cap areg `var' dev_* [aw=pwgt4], abs(powtract_year)
	if _rc==0 {
		predict `var'_hat, d
		replace `var'_hat=`var'_hat + _b[_cons]  //recenter prediction around mean
		predict `var'_comp, xb
                post `memhold' ("`s'") ("`ii'") ("`var'") (e(N)) (e(df_m))
        }
	if _rc!=0 {
		gen `var'_hat = .
		gen `var'_comp = .
		di "No adjusted information in countyid==`ii' for variable `var'"
	}
	}
 
	collapse lnwage2_pow_hat lnwage2_local_hat lnwage2_nonlocal_hat   lnwkwage2_pow_hat lnwkwage2_local_hat lnwkwage2_nonlocal_hat   lnincw2_pow_hat lnincw2_local_hat lnincw2_nonlocal_hat *_comp, by(powtractid90 year) fast
	if `ii'>1 append using `predicted'
	save `predicted', replace
	if `ii'==`powcitycount' save "$intermediate/LNWAGE/lnwage2_local_nonlocal_FE_`c'.dta", replace
	}
	}

	**************** OUTSIDE *****************

	if "`sample'"=="outside"{
	**DATA FOR OUTSIDE VARS**
	keep year pwgt3 pwgt4 lnwage2_outside   lnwkwage2_outside    lnincw2_outside age agesq age3 age4 hs coll inschool black other male powprogid_power progid_power tractid90 sample_winlose
	keep if sample_winlose==1&pwgt4!=.
	**** Identifiers
	egen countyid=group(progid_power)
	egen powcountyid=group(powprogid_power)
	
	***Demean for areg
	foreach var of varlist age agesq age3 age4 hs coll inschool black other male{
	        gen aux1=`var'*pwgt4
		egen aux2=sum(pwgt4) if `var'!=.&year==1990, by(countyid)
		egen `var'_mean=sum(aux1/aux2) if `var'!=.&year==1990, by(countyid)
		egen `var'_mean2=mean(`var'_mean), by(countyid) //fillin for other decades
		gen dev_`var'=`var'-`var'_mean2
		drop `var' `var'_mean `var'_mean2 aux1 aux2
	}
	
	compress
	tempfile tempcenperson
	save `tempcenperson', replace



	use `tempcenperson', clear
	su countyid
	local citycount = r(max)
	tempfile predicted
	forvalues ii = 1(1)`citycount'{
	di `ii'
	use `tempcenperson' if countyid==`ii', clear
	
	egen tract_year = group(tractid90 year)
	
	foreach var of varlist lnwage2_outside lnwkwage2_outside lnincw2_outside {
	cap drop `var'_hat
	cap drop `var'_comp
	cap areg `var' dev_* [aw=pwgt4], abs(tract_year)
	if _rc==0{
		predict `var'_hat, d
		replace `var'_hat=`var'_hat + _b[_cons] //recenter prediction around mean
                predict `var'_comp, xb
                post `memhold' ("`s'") ("`ii'") ("`var'") (e(N)) (e(df_m))
	}
	if _rc!=0 {
		gen `var'_hat = .
		gen `var'_comp = .
		di "No adjusted information in countyid==`ii' for variable `var'"
	}
	}
	
	collapse lnwage2_outside_hat lnwkwage2_outside_hat lnincw2_outside_hat *_comp, by(tractid90 year) fast
	if `ii'>1 append using `predicted'
	save `predicted', replace
	if `ii'==`citycount' save "$intermediate/LNWAGE/lnwage2_outside_FE_`c'.dta", replace
	}
	}

  local c = `c'+1
}
  

*** APPEND DATASET POW
if "`sample'"=="pow"{
local c = `c'-1
use "$intermediate/LNWAGE/lnwage2_local_nonlocal_FE_1.dta", clear
  forvalues s = 2(1)`c'{
    noisily append using "$intermediate/LNWAGE/lnwage2_local_nonlocal_FE_`s'.dta"
   }

*Winsorize at 80% and 40x min wage
foreach var of varlist lnwage2_pow_hat lnwage2_local_hat lnwage2_nonlocal_hat{
replace `var'=log(.8*2.90) if `var'<log(.8*2.90)&year==1980
replace `var'=log(40*2.90) if `var'>log(40*2.90)&year==1980&`var'!=.
replace `var'=log(.8*3.35) if `var'<log(.8*3.35)&year==1990
replace `var'=log(40*3.35) if `var'>log(40*3.35)&year==1990&`var'!=.
replace `var'=log(.8*5.15) if `var'<log(.8*5.15)&year==2000
replace `var'=log(40*5.15) if `var'>log(40*5.15)&year==2000&`var'!=.
}

compress
save "$intermediate/lnwage2_local_nonlocal_FE.dta", replace
}

*** APPEND DATASET OUTSIDE
if "`sample'"=="outside"{
local c = `c'-1
use "$intermediate/LNWAGE/lnwage2_outside_FE_1.dta", clear
  forvalues s = 2(1)`c'{
    noisily append using "$intermediate/LNWAGE/lnwage2_outside_FE_`s'.dta"
   }

*Winsorize at 80% and 40x min wage
replace lnwage2_outside_hat=log(.8*2.90) if lnwage2_outside_hat<log(.8*2.90)&year==1980
replace lnwage2_outside_hat=log(40*2.90) if lnwage2_outside_hat>log(40*2.90)&year==1980&lnwage2_outside_hat!=.
replace lnwage2_outside_hat=log(.8*3.35) if lnwage2_outside_hat<log(.8*3.35)&year==1990
replace lnwage2_outside_hat=log(40*3.35) if lnwage2_outside_hat>log(40*3.35)&year==1990&lnwage2_outside_hat!=.
replace lnwage2_outside_hat=log(.8*5.15) if lnwage2_outside_hat<log(.8*5.15)&year==2000
replace lnwage2_outside_hat=log(40*5.15) if lnwage2_outside_hat>log(40*5.15)&year==2000&lnwage2_outside_hat!=.


compress
save "$intermediate/lnwage2_outside_FE.dta", replace
}


*********************************
*** export diagnostic results ***
*********************************
postclose `memhold'
use `results', clear
save "$intermediate/LNWAGE/`sample'_cell_prediction_model_Ns.dta", replace

timer off 1
timer list
di "MINUTES="r(t1)/60
di "HOURS="r(t1)/60/60
cap log close
