

capture program drop formatable
program define formatable

syntax varlist(min=2 max=4), depvars(string) select(string) ord(string) [stars]
qui {
 tokenize `varlist'
 local coeff = "`1'"
 local se = "`2'"
 if "`stars'"!="" local Star = "`3'"
 local N = "`4'"

 local s: word count `select'

 ** check that variables only vary by `select'
 egen group = group(`select')
 duplicates tag  `depvars' group, gen(tag)
 sum tag
 if r(max)>0{
    di in red "estimator varies within `depvars'-`select'."
    di in red "Should keep only the relevant point estimates."
    error 498
 }
 drop tag
 ** format coeffs, se and stars
 gen aux = string(round(`coeff',0.001),"%9.3f")
 drop `coeff'
 ren aux `coeff'

 gen aux = "["+string(round(`se',0.001),"%9.3f")+"]"
 drop `se'
 ren aux `se'

 gen aux = "("+string(`N')+")"
 drop `N'
 ren aux `N'

 if "`stars'"!="" replace `se' = `se'+`Star'

 keep `depvars' `select' `coeff' `se' `N' `ord' group 

 preserve
 keep `depvars' `select' `coeff' `ord' group
 tempfile coefficients
 save `coefficients', replace
 restore

 preserve
 keep `depvars' `select' `N' `ord' group
 tempfile obs
 save `obs', replace
 restore
 
 keep `depvars' `select' `se' `ord' group
 append using `coefficients'
 append using `obs'
 
 gen     order = 1 if `coeff'!=""
 replace order = 2 if `se'!=""
 replace order = 3 if `N'!=""

 gen col =  `coeff'
 replace col =  `se' if `se'!="" & `N'=="" & `coeff'=="" 
 replace col =  `N'  if `se'=="" & `N'!="" & `coeff'=="" 
 drop `coeff' `se' `N'
 sort `ord' `depvars' `select' order

 gen length = length(col)
 sum  length if  order==1
 gen dlength= r(max)-length if order==1
 replace  col = " "+col if order==1 & dlength ==1
 drop dlength length
 gen length = length(col)
 sum  length
 gen dlength= r(max)-length
 replace  col =  col+" " if dlength==1
 replace  col =  col+"  " if dlength==2
 replace  col =  col+"   " if dlength==3
 replace  col =  col+"    " if dlength==4
 replace  col =  col+"     " if dlength==5
 replace  col =  col+"      " if dlength==6
 replace  col =  col+"       " if dlength==7
 replace  col =  col+"        " if dlength==8
 replace  col =  col+"         " if dlength==9

 drop length dlength

 gen stat = "`coeff'" if order==1
 replace stat = "`se'" if order==2
 replace stat = "`N'"  if order==3
 replace order = _n

 sum group
 local G = r(max)

 forvalues g = 1(1)`G'{
   preserve
   keep if group==`g'
   replace order = _n

   tokenize `select'
   forvalues i = 1(1)`s'{
     local select`i' = "``i''"
     levelsof `select`i'', local(values`i')
   }

   drop `select'
   count
   local n = r(N)+`s'+1
   set obs `n'

   replace order = 0 if order==.
   sort order `depvars'

   forvalues i = 1(1)`s'{
      replace `depvars' = "`i'-`select`i''"  in `i'
      replace `ord'     = `i'                in `i'
   }

   forvalues i = 1(1)`s'{
      cap replace col = "`values`i''"  in `i'
      cap replace col = `values`i''  in `i'
   }

   local s1 = `s'+1
   replace `depvars' = "`s1'.----------" in `s1'
   replace `ord'     =  `s1'              in `s1'
   replace col  = "----------" in `s1'
   ren col col`g'

   order `depvars' stat col
   replace order = _n
   replace order = . if _n>`s1'
   replace stat = string(order) if stat=="" & order!=.
   replace stat = "1. coeff" if stat=="coeff"
   replace stat = "2.    se" if stat=="se"
   replace stat = "3.   obs" if stat=="N"
   drop order
   drop group
   sort `ord' `depvars' stat
   tempfile group`g'
   save `group`g'', replace
   restore
  }
  
 use `group1', clear
 forvalues g = 2(1)`G'{
   merge `ord' `depvars' stat using `group`g'' 
   drop _m
   sort `ord' `depvars' stat
 }

  gen order = _n
  egen group = group(`depvars')
  sum group
  local V = r(max)-2
  local N = r(N)
  local newN= `N'+`V'+2
  set obs `newN'
  replace stat = "4.      " if stat==""
  local fin = `V'-1
  forvalues i =0(1)`fin'{
    local n = 3*(`i'+1)
    local w = 3*(`V'+1)+`i'
    replace `ord'    = `ord'[`n']  in `w' if outcome==""
    replace outcome = outcome[`n'] in `w' if outcome==""
   }

 drop order group
 sort `ord' `depvars' stat

 replace  `depvars' = "" if  stat=="2.    se"
 replace  `depvars' = "" if  stat=="3.   obs"
 replace  `depvars' = "" if  stat=="4.      "

 replace  stat = " coeff" if  stat=="1. coeff"
 replace  stat = "    se" if  stat=="2.    se"
 replace  stat = "   obs" if  stat=="3.   obs"
 replace  stat = "      " if  stat=="4.      "
 replace  stat = "      " if  stat=="1"
 replace  stat = "      " if  stat=="2"
 replace  stat = "      " if  stat=="3"

 drop if `ord'==.
 drop `ord'
 }
end


** Example: formatable TOT se_TOT star,  depvars(variable) select(estimator adjusted samehouse) stars


