cap program drop spatialma_loo_norm
program define spatialma_loo_norm, byable(recall)

syntax varlist [if], latitude(string) longitude(string) [distance(real 1)] 

marksample touse, novarlist

* Matrix of varlist for MATA
foreach var of local varlist {
   qui sum `var' if `touse'
   if r(N)==0 {
      qui gen `var'_backup = `var' if `touse'
      qui replace `var' = 0 if `touse'
   }
}

local vars: word count `varlist'
mat b=J(`vars',1,.)
mat rownames b = `varlist'

mata:  var = st_matrixrowstripe("b")
mata: varlist = var[.,2]

foreach var of local varlist {
   cap sum `var'_backup if `touse'
   if _rc==0 {
      qui replace `var' = `var'_backup if `touse'
      cap drop `var'_backup
   }
}


* Matrix with radius into MATA
matrix radius = `distance'
mata: radius  = st_matrix("radius")

mata: MA = spatial_ma_loo_norm("`latitude'", "`longitude'", "`touse'", varlist, radius)

* Export variables from MATA to STATA
local i = 1
foreach var of local varlist {
   cap confirm var `var'_sma
   if _rc!=0 {
      qui gen double `var'_sma = .
   }
   mata: st_store(., "`var'_sma", "`touse'", MA[.,`i'])
   local i = `i'+1
   }

end

*mata: mata clear

mata:
real matrix spatial_ma_loo_norm(string scalar latvar, string scalar longvar, string scalar usevar, string vector varlist, numeric scalar radius)
 {
   latitude =st_data(., latvar, usevar)
   longitude=st_data(.,longvar, usevar)
   n        =rows(latitude)
   lat      =latitude*pi()/180
   longitude=longitude*pi()/180

   V = J(rows(lat) ,rows(lat),1)
   R=3963 - 13*sin(lat[1])
   dlat  = lat:*V :-lat'
   dlong = longitude:*V :-longitude'
   lati  = lat:*V
   latj  = lat':*V
   a     = sin(dlat:/2):^2 + cos(lati):*cos(latj):*sin(dlong:/2):^2
   d     = sqrt(a)
   //min   = (d:<=radius):*d + (d:>radius)  //this seems redundant   
   c     = 2*asin(d)
   D     = R*c

   X = st_data(., varlist', usevar)

   w = normalden(D/.5) //bandwidth (as opposed to radius) is .5
   w = w:*(D:>.01):*(D:<radius)
   k = cols(X)
   MA = J(n,k,.)

   for (i=1; i<=k; i++) {
      thisx=editvalue(X[.,i],.,0)
      w2=w:*(X[.,i]:<.)  //missing patterns may differ by covariate
      N = colsum(w2)'  //this is the correct denominator w/ missingness
      a = w2:*thisx
      b = colsum(a)'
      MA[.,i] = b:/N
      }

return(MA)

}

end

