version 11
cap run "/rdcprojects/mc1/mc00535/programs_organize/3.estimation/1.setup.do"
if _rc!=0 di in red "run 1.setup.do"

use "$censusdir/workfile_90_fullcounties_prepped.dta", clear 
cap ren county90 county
cap drop __000000 


** 2. identify winlose sample (WARNING: This way of identifying winlose sample is recursive!)
cap drop _m
cap gen trimsample=1

************************************************
*** Compute geographic distance and prep data***
************************************************
*** Keep only EZ cities
    gen cityname=city
    replace cityname = trim(regexr(regexr(cityname,"city","")," ",""))
    gen citykeep = 0
    foreach city in Atlanta Baltimore Chicago Detroit NewYork Philadelphia{  /*Cleveland LosAngeles are currently out*/
	qui sum cg if cityname=="`city'"
        replace citykeep = 1 if cg==r(mean)
        replace cityname = "`city'" if cg==r(mean) & cityname=="" & citykeep==1
    }
    keep if citykeep==1
    drop city citykeep 
    tab city assigned_tract  if yr==3

*** Take out Yonkers, NY (which is assigned_tract = 0 in winlose)
    replace RCs_in_EZcities = 1 if city=="NewYork" & assigned_tract ==0	

*** Get citynames and make all nonEZ tracts assigned_tract=0
    egen city=group(cg)
    replace assigned_tract=0 if assigned_tract==.
    tempfile workingdata
    save `workingdata', replace
*** Compute distance between treated and untreated tracts within city
*** and save it in a dataset containing tractid90 and distance
    collapse latitude longitude assigned_tract, by(tractid90 city)
    sum city
    local max = r(max)
    tempfile working
    forvalues i = 1(1)`max'{
        preserve 
	keep if city==`i'
   	earthdistance  latitude longitude assigned_tract
   	gen distance = d
   	keep tractid90 distance
   	tempfile distance`i'
   	save `distance`i'', replace
   	restore
     }
     use `distance1', clear
     forvalues i = 2(1)`max'{
       append using `distance`i''
     }
    sort tractid90
    save "$censusdir/distance.dta", replace

*** Merge to distance workfile
    use `workingdata', clear
    sort tractid90
    merge tractid90 using "$censusdir/distance.dta"
    tab _merge
    drop _m
*** Program constraints
    foreach var in unemployed poverty pop hh{
      cap drop `var'_90 big_`var'
      gen `var'_90=`var' if year==1990
      egen big_`var'=mean(`var'_90), by(tractid90)
    }
    tab city assigned_tract  if yr==3
    drop if (big_poverty<0.2 | big_unemployed<0.063)
    drop if big_hh<200      | big_pop<500
    tab city assigned_tract  if yr==3

*******************************************
*** Find Placebo Tracts                 ***
*******************************************
*** Interact variables with city dummies
    cap drop __000000
    tab city, gen(city_)
    foreach var of global PCBO_interactions{
      forvalues i = 1(1)`max'{
      gen `var'_`i' = `var'*city_`i'
      }
     }

*** Build globals
    foreach var of global PCBO_interactions{
     global PCBO_`var' ""
     forvalues c = 1(1)`max'{
     local `var'_`c' = "`var'_`c'"
      global PCBO_`var': list global(PCBO_`var') | local(`var'_`c')
     }
    }

*** Find placebo tracts only for those assigned_tracts==1 in the trimmed sample
    replace assigned_tract = . if trimsample!=1 & assigned_tract==1

*** Estimate selection equation (similar to spec 1 but with flexible slopes for unempl, lnpop and poverty and with city FE).
    tsset id yr			
    logit assigned_tract l.($PCBO_poverty $PCBO_unemployed $PCBO_lnpop $PCBO_lnjobs) $PCBO_1 $PCBO_2 $PCBO_3 $PCBO_4 $PCBO_5 $PCBO_6 city_* if yr==4 & (RCs_in_EZcities!=1|assigned_tract==1), asis
    
    predict p if e(sample)
    egen phat = mean(p), by(id)
    drop city_* p

    * These are EZ tracts with missing covariates, thus with missing phat, thus with no placebo tract matched to it
    tab city if assigned_tract ==1 & phat!=. & yr==3
    tab city if assigned_tract ==0 & phat!=. & yr==3

** Keep only relevant information to find placebo tracts
    keep if yr==3
    keep tractid90 id city assigned_tract phat distance
    * holders
    gen assigned_placebo      = .
    gen assigned_placeboclose = .
    gen assigned_placebofar   = .

** Find placebo tracts using NN-match without replacement on pscore
    forvalues t = 1(1)`max'{
       psmatch2 assigned_tract if city==`t', pscore(phat) n(1) noreplacement
       replace assigned_placebo = 1 if city==`t' & assigned_tract==0 & _weight==1  

       psmatch2 assigned_tract if city==`t' & (distance==0 | distance<=1), pscore(phat) n(1) noreplacement
       replace assigned_placeboclose = 1 if city==`t' & assigned_tract==0 & _weight==1  

       psmatch2 assigned_tract if city==`t' & (distance==0 | (distance>1 & distance<.)), pscore(phat) n(1) noreplacement
       replace assigned_placebofar = 1 if city==`t' & assigned_tract==0 & _weight==1
       }

    tab city  assigned_placebo
    tab city  assigned_placebofar

** Rearrange dataset and keep only relevant information
    label var assigned_placebo       "Nearest Neighbor pscore st EZ=0"
    label var assigned_placeboclose  "Nearest Neighbor pscore st EZ=0 & distance in (0,1]"
    label var assigned_placebofar    "Nearest Neighbor pscore st EZ=0 & distance in (1,infty)"

    keep if assigned_placebo==1 | assigned_placeboclose==1 | assigned_placebofar==1
    keep tractid90 assigned_placebo assigned_placeboclose assigned_placebofar
    compress
    sort tractid90 
    cap drop __000000
    save "$censusdir/placebo_tracts_raw.dta", replace


***********************************************************
*** Prepare workfile for placebo estimation             ***
***********************************************************
*** Get Covariates for the placebo tracts
    use "$censusdir/workfile_90_fullcounties_prepped.dta", clear 
    merge m:1 tractid90  using "$censusdir/placebo_tracts_raw.dta"
    tab _merge
    drop _merge
    keep if assigned_tract!=. | (assigned_placebo==1 | assigned_placeboclose==1 | assigned_placebofar==1)
    replace assigned_placebo = 0      if assigned_tract==0
    replace assigned_placeboclose = 0 if assigned_tract==0 
    replace assigned_placebofar = 0   if assigned_tract==0 

*** 2. identify winlose sample (WARNING: This way of identifying winlose sample is recursive!)
    cap drop _m
*** Fix city variable
    qui sum cg
    local max = r(max)
    forvalues i = 1(1)`max'{
       cap levelsof city if cg==`i', local(name)
       cap replace city = `name' if cg==`i' & city==""
    }

*** Fix RC
    replace RCs_in_EZcities = 1 if city=="New York city" & assigned_tract ==0	

*** Only use controls that are in the trimmed sample
    cap gen trimsample=1
    replace assigned_placebo = .      if assigned_tract==0 & trimsample!=1
    replace assigned_placeboclose = . if assigned_tract==0 & trimsample!=1
    replace assigned_placebofar = .   if assigned_tract==0 & trimsample!=1

*** Fix progid
    gen ezcity = 0
    foreach val in Atlanta Baltimore Chicago Detroit Philadelphia{
      qui sum cg if city=="`val' city"
      replace ezcity = 1 if cg==r(mean)
      }
      qui sum cg if city=="New York city" 
      replace ezcity = 1 if cg==r(mean)
    cap drop aux1
    cap drop aux2
    gen aux1 = progid_power if ezcity==1 & progid_power<=8
    egen aux2 = max(aux1) if ezcity==1, by(city)
    gen     progid_placebo=aux2         if assigned_placebo==1 | assigned_placeboclose==1 | assigned_placebofar==1
    replace progid_placebo=progid_power if assigned_placebo==0
    drop aux1 aux2


sort tractid90 year
compress
save "$censusdir/workfile_90_placebo.dta", replace


 